<?php
/**
* Appointment Controller
*/
class AppointmentController extends Controller
{
	private $appointmentModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize appointment model*/
		$this->appointmentModel = new Appointment();
	}

	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		$data['doctors'] = $this->appointmentModel->getDoctors();
		$data['result'] = $this->appointmentModel->allAppointments();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*call appointment list view*/
		$this->view->render('appointment/appointment_list.tpl', $data);
	}
	/**
	* Appointment index add method
	* This method will be called on Appointment add
	**/
	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add Appointment';
		/* Set empty data to array */
		$data['result'] =  NULL;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['doctors'] = $this->appointmentModel->getDoctors();
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'appointment/action';
		/*Render Blog add view*/
		$this->view->render('appointment/appointment_add.tpl', $data);
	}
	/**
	* Appointment index edit method
	* This method will be called on Appointment edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to blog list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('appointment');
		}
		/**
		* Call getBlog method from Blog model to get data from DB for single blog
		* If blog does not exist then redirect it to blog list view
		**/
		$appointment = $this->appointmentModel->getAppointment($id);
		if (!$appointment) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Appointment does not exist in database!');
			$this->url->redirect('appointment');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set Edit blog page title */
		$data['page_title'] = 'Edit Appointment';
		/* Set Blog data to array */
		$data['result'] =  $appointment;
		$data['doctors'] = $this->appointmentModel->getDoctors();
		$data['pharmacy'] = json_encode($this->appointmentModel->getPharmacy());
		$data['reports'] = $this->appointmentModel->getReports($id);
		
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'appointment/action';
		/*Render Blog edit view*/
		$this->view->render('appointment/appointment_form.tpl', $data);
	}
	/**
	* Appointment index action method
	* This method will be called on appointment submit/save view
	**/
	public function indexAction()
	{
		/**
		* Validate form input field
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/	
		if ($validate_field = $this->validateField()) {
			$this->session->data['message']['MESSAGE'] = array('alert' => 'danger', 'value' => 'Please enter/select valid '.implode(", ",$validate_field).'!');
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('appointment/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('appointment/add');
			}
		}

		if ($this->commons->validateToken($this->url->post('_token'))){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('appointment/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('appointment/add');
			}
		}
		/**
		* It's update call or create call
		* According to them call that metthod
		**/
		if (!empty($this->url->post('id'))) {
			$this->update();
		}
		else {
			$this->create();
		}
	}
	/**
	* Appointment index delete method
	* This method will be called on blog delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('appointment');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	public function indexAppointment()
	{
		$date = $this->url->post('date');
		$doctor = $this->url->post('doctor');
		/** 
		* Check if request is POST or not 
		* Validate input field
        **/
		if (!$this->validate($date, $doctor)) {
			echo "No_Slot";
			exit();
		}
		/** 
		* Get doctor timing from db
        **/
		$this->createAppointmentSlot($date, $doctor);
	}

	public function dashboardAppointmentAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('dashboard');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter/select valid '.implode(", ",$validate_field).'!');
			$this->url->redirect('dashboard');
		}
		/**
		* It's update call or create call
		* According to them call that metthod
		**/
		if (!empty($this->url->post('id'))) {
			$this->dashboardAppointmentUpdate();
		} else {
			$this->create();
		}
	}
	/**
	* Update method 
	* This method will be called on appointment update or submit
	**/
	protected function update()
	{
		/**
		* Get all post request to array
		* Set value to array
		**/
		$data['id'] = $this->url->post('id');
		$data['name'] = $this->url->post('name');
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['department'] = $this->url->post('department');
		$data['doctor'] = $this->url->post('doctor');
		$data['date'] = date_format(date_create($this->url->post('date')), "Y-m-d");
		$data['time'] = $this->url->post('time');
		$data['status'] = $this->url->post('status');
		$data['note'] = $this->url->post('note');
		$data['doctornote'] = $this->url->post('doctornote');
		$data['prescription_id'] = $this->url->post('prescription_id');
		$data['prescription'] = json_encode($this->url->post('prescription'));
		/**
		* Call update appointment method from appointment model
		* On success or error redirect back to page
		**/
		$result = $this->appointmentModel->updateAppointment($data);
		if (!empty($data['prescription_id'])) {
			$this->appointmentModel->updatePrescription($data);
		} else {
			$this->appointmentModel->createPrescription($data);
		}

		if ($this->url->post('sendmail')) {
			$message = file_get_contents(DIR_APP.'views/mail_template/update-appointment.tpl');
			$message = str_replace('{name}', $data['name'], $message);
			$message = str_replace('{site_name}', NAME, $message);
			$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
			$mailer = new Mailer();
			$mailer->mail->setFrom(SITEEMAIL, NAME);
			$mailer->mail->addAddress($data['email'], $data['name']);
			$mailer->mail->isHTML(true);
			$mailer->mail->Subject = 'Appointment Updated at '.NAME;
			$mailer->mail->Body = $message;
			$mailer->mail->AltBody = 'Hello '.$data['name'].'.
			Your Appointment has been updated. To track your Appointment details please log in to your account.';
			$mailer->sendMail();
		}
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Appointment updated successfully.');
		$this->url->redirect('appointment/edit&id='.$data['id']);
	}

	public function dashboardAppointmentUpdate()
	{
		$data['id'] = $this->url->post('id');
		$data['name'] = $this->url->post('name');
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['department'] = $this->url->post('department');
		$data['doctor'] = $this->url->post('doctor');
		$data['date'] = date_format(date_create($this->url->post('date')), "Y-m-d");
		$data['time'] = $this->url->post('time');
		$data['status'] = $this->url->post('status');
		$result = $this->appointmentModel->dashboardUpdateAppointment($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Appointment updated successfully.');
		$this->url->redirect('dashboard');
	}

	protected function create()
	{
		$data['name'] = $this->url->post('name');
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['department'] = $this->url->post('department');
		$data['doctor'] = $this->url->post('doctor');
		$data['date'] = date_format(date_create($this->url->post('date')), "Y-m-d");
		$data['time'] = $this->url->post('time');
		$data['status'] = $this->url->post('status');
		$data['appointment_id'] = date('Ymd').rand(10,1000).date('his');
		if ($result = $this->appointmentModel->createAppointment($data)) {
			$doctor = $this->appointmentModel->getDoctorData($data['doctor']);
			$message = file_get_contents(DIR_APP.'views/mail_template/create-appointment.tpl');
			$message = str_replace('{name}', $data['name'], $message);
			$message = str_replace('{email}', $data['email'], $message);
			$message = str_replace('{mobile}', $data['mobile'], $message);
			$message = str_replace('{doctor}', $doctor['name'], $message);
			$message = str_replace('{date}', $data['date'], $message);
			$message = str_replace('{time}', $data['time'], $message);
			$message = str_replace('{appointment_id}', $data['appointment_id'], $message);
			$message = str_replace('{site_name}', NAME, $message);
			$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
			$mailer = new Mailer();
			$mailer->mail->setFrom(SITEEMAIL, NAME);
			$mailer->mail->addAddress($data['email'], $data['name']);
			$mailer->mail->addBCC($doctor['email'], $doctor['name']);
			$mailer->mail->isHTML(true);
			$mailer->mail->Subject = 'Appointment Created at '.NAME;
			$mailer->mail->Body = $message;
			$mailer->mail->AltBody = 'Hello '.$data['name'].'.
			Your Appointment has been booked on '.$data['date'].' at '.$data['time'].'.
			Your Appointment ID : '.$data['appointment_id'].'';		
			$mailer->sendMail();
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Appointment created successfully.');
			$this->url->redirect('appointment/edit&id='.$result);
		} else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Appointment does not created (Server Error).');
			$this->url->redirect('appointment/add');
		}
	}

	protected function createAppointmentSlot($date, $doctor)
	{
		if (!$time = json_decode($this->appointmentModel->getDoctorTime($doctor), true)) {
			echo "No_Slots";
			exit();
		}
		$time_slot = $this->makeSlot($time);
		$booked_slot = $this->appointmentModel->bookedSlot($date, $doctor);
		
		$slot = [];
		$flag = 0;
		foreach ($time_slot as $key => $time) {
			foreach ($booked_slot as $booked) {
				if ($time === $booked) {
					$flag++;
				}
			}
			$slot[] = array(
				'time' => $time,
				'status' => $flag
				);
			$flag = 0;
		}
		echo json_encode($slot);
	}

	protected function makeSlot($time)
	{
		$time_slot = [];
		$st1 = strtotime($time['st1']);
		$et1 = strtotime($time['et1']);
		$st2 = strtotime($time['st2']);
		$et2 = strtotime($time['et2']);
		while ($st1 < $et1) {
			$time_slot[] = date ("H:i", $st1);
			$st1 += $time['slot']*60;
		}
		while ($st2 < $et2) {
			$time_slot[] = date ("H:i", $st2);
			$st2 += $time['slot']*60;
		}
		return $time_slot;
	}
	/** 
	* Validate form input field on server side
	**/
	protected function validate($date, $doctor)
	{
		if (filter_var($doctor, FILTER_VALIDATE_INT) === false) {
			/** 
			* If doctor is not int 
			* Return false
			**/
			return false;
		}
		elseif (!$this->validateDate($date) || strtotime($date) < strtotime(date('Y-m-d'))) {
			/** 
			* If date is not valid
			* also date is less than today 
			* Return false
			**/
			return false;
		}
		else {
			return true;
		}
	}
	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['name'] = 'name';
		}

		if ($this->commons->validateEmail($this->url->post('email'))) {
			$error_flag = true;
			$error['email'] = 'email address';
		}

		if ($this->commons->validatePhoneNumber($this->url->post('mobile'))) {
			$error_flag = true;
			$error['mobile'] = 'mobile number';
		}

		if ($this->commons->validateDate($this->url->post('date'))) {
			$error_flag = true;
			$error['date'] = 'date';
		}

		if ($this->commons->validateNumber($this->url->post('doctor'))) {
			$error_flag = true;
			$error['doctor'] = 'doctor';
		}

		if ($this->commons->validateNumber($this->url->post('department'))) {
			$error_flag = true;
			$error['department'] = 'department';
		}

		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
	/** 
	* function to check Date format 
	* If matches then good else invalidate
	**/	
	protected function validateDate($date, $format = 'Y-m-d')
	{
		$d = DateTime::createFromFormat($format, $date);
		return $d && $d->format($format) == $date;
	}

	protected function delete()
	{
		$result = $this->appointmentModel->deleteAppointment($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Appointment deleted successfully.');
		$this->url->redirect('appointment');
	}
}