<?php

/**
* Blog Controller
*/
class BlogController extends Controller
{
	/**
	* Private Blog model variable
	* This will be used for calling Blog model's function
	**/
	private $blogModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/* Intilize Blog model */
		$this->blogModel = new Blog();
	}
	/**
	* Blog index method
	* This method will be called on blog list view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all blogs data from DB using blog model 
		**/
		$data['result'] = $this->blogModel->allBlogs();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*Render Blog view*/
		$this->view->render('blog/blog_list.tpl', $data);
	}
	/**
	* Blog index add method
	* This method will be called on Blog add
	**/
	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add Blog';
		/* Set empty data to array */
		$data['result'] =  NULL;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['categories'] = $this->blogModel->allCategory();
		$categories = array();
		if (!empty($data['categories'])) {
			foreach ($data['categories'] as $value){
				$categories[$value['parent']][] = $value;
			}

			$data['categories'] = $this->createCategoryArray($categories, $categories[0]);
			$data['categories'] = $this->createCategoryHTML($data['categories']);
		} else {
			$data['categories'] = "";
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'blog/action';
		/*Render Blog add view*/
		$this->view->render('blog/blog_form.tpl', $data);
	}
	/**
	* Blog index edit method
	* This method will be called on Blog Edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to blog list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('blog');
		}
		/**
		* Call getBlog method from Blog model to get data from DB for single blog
		* If blog does not exist then redirect it to blog list view
		**/
		$blog = $this->blogModel->getBlog($id);
		if (!$blog) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Blog does not exist in database!');
			$this->url->redirect('blog');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set Edit blog page title */
		$data['page_title'] = 'Edit Blog';
		/* Set Blog data to array */
		$data['result'] =  $blog;
		$data['categories'] = $this->blogModel->allCategoryWithCheck($id);

		$categories = array();
		/*foreach ($data['categories'] as $value){
			$categories[$value['parent']][] = $value;
		}

		$data['categories'] = $this->createCategoryArray($categories, $categories[0]);

		$data['categories'] = $this->createCategoryHTML($data['categories']);*/
		if (!empty($data['categories'])) {
			foreach ($data['categories'] as $value){
				$categories[$value['parent']][] = $value;
			}

			$data['categories'] = $this->createCategoryArray($categories, $categories[0]);
			$data['categories'] = $this->createCategoryHTML($data['categories']);
		} else {
			$data['categories'] = "";
		}
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'blog/action';
		/*Render Blog edit view*/
		$this->view->render('blog/blog_form.tpl', $data);
	}

	protected function createCategoryHTML($categories)
	{
		$data = '<ul class="category-list">';
		foreach($categories as $value){
			if(isset($value['sub'])){
				$data .= '<li><input type="checkbox" name="category[]" value="'.$value['id'].'" id="category-'.$value['id'].'" '.$value['status'].' ><label for="category-'.$value['id'].'"><span><i class="fa fa-check"></i></span><p>'.$value['name'].'</p></label>' .$this->createCategoryHTML($value['sub']).'</li>';
			}else{
				$data .= '<li><input type="checkbox" name="category[]" value="'.$value['id'].'" id="category-'.$value['id'].'" '.$value['status'].' ><label for="category-'.$value['id'].'"><span><i class="fa fa-check"></i></span><p>'.$value['name'].'</p></label></li>';
			}
		}
		return $data.'</ul>';
	}
	
	protected function createCategoryArray(&$list, $parent)
	{
		$tree = array();
		foreach ($parent as $k=>$l){
			if(isset($list[$l['id']])){
				$l['sub'] = $this->createCategoryArray($list, $list[$l['id']]);
			}
			$tree[] = $l;
		}
		return $tree;
	}

	/**
	* Blog index action method
	* This method will be called on blog submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('blog');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('blog/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('blog/add');
			}
		}

		if ($this->commons->validateToken($this->url->post('_token'))){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('blog/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('blog/add');
			}
		}

		if (!empty($this->url->post('id'))) {
			$this->update();
		}
		else {
			$this->create();
		}
	}
	/**
	* Blog index delete method
	* This method will be called on blog delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('blog');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	/**
	* Blog Update function 
	* This method will be called on blog submit/save view
	**/
	protected function update()
	{
		$data['id'] = $this->url->post('id');
		$data['title'] = $this->url->post('title');
		$data['picture'] = $this->url->post('blog-picture');
		$data['short_post'] = $this->url->post('short_post');
		$data['long_post'] = $this->url->post('long_post');
		$data['author'] = $this->url->post('author');
		$data['status'] = $this->url->post('status');
		$data['category'] = $this->url->post('category');

		$this->blogModel->updateBlog($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Blog updated successfully.');
		$this->url->redirect('blog/edit&id='.$data['id']);
	}

	protected function create()
	{
		$data['title'] = $this->url->post('title');
		$data['picture'] = $this->url->post('blog-picture');
		$data['short_post'] = $this->url->post('short_post');
		$data['long_post'] = $this->url->post('long_post');
		$data['author'] = $this->url->post('author');
		$data['status'] = $this->url->post('status');
		$data['user_id'] = $this->session->data['user_id'];
		$data['category'] = $this->url->post('category');

		if ($result = $this->blogModel->createBlog($data)) {
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Blog created successfully.');
			$this->url->redirect('blog/edit&id='.$result);
		} else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Blog does not created (Server Error).');
			$this->url->redirect('blog/add');
		}
	}

	protected function delete()
	{
		$result = $this->blogModel->deleteBlog($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Blog deleted successfully.');
		$this->url->redirect('blog');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($this->commons->validateText($this->url->post('title'))) {
			$error_flag = true;
			$error['title'] = 'Blog Title!';
		}

		if ($this->commons->validateText($this->url->post('author'))) {
			$error_flag = true;
			$error['author'] = 'Author Name!';
		}

		if ($this->commons->validateText($this->url->post('short_post'))) {
			$error_flag = true;
			$error['short_post'] = 'Short Description!';
		}
		
		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}