<?php

/**
 * Category Controller
 */
class CategoryController extends Controller {

	/**
	 * Private Category model variable
	 * This will be used for calling Category model's function
	 **/
	private $blogModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/* Intilize Blog model */
		$this->categoryModel = new Category();
	}

	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all blogs data from DB using blog model 
		**/
		$data['result'] = $this->categoryModel->allCategories();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'category/action';
		/*Render Blog view*/
		$this->view->render('blog/category.tpl', $data);
	}

	/**
	* Blog index edit method
	* This method will be called on Blog edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to blog list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('category');
		}
		/**
		* Call getBlog method from Blog model to get data from DB for single blog
		* If blog does not exist then redirect it to blog list view
		**/
		$category = $this->categoryModel->getCategory($id);
		if (!$category) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Category does not exist in database!');
			$this->url->redirect('category');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set Edit blog page title */
		$data['page_title'] = 'Edit Category';
		/* Set Blog data to array */
		$data['result'] =  $category;
		$data['categories'] = $this->categoryModel->allCategories();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'category/action';
		/*Render Blog edit view*/
		$this->view->render('blog/category_form.tpl', $data);
	}
	/**
	* Category index action method
	* This method will be called on Category submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('category');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('category/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('category');
			}
		}

		if ($this->commons->validateToken($this->url->post('_token'))){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('category/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('category');
			}
		}

		if (!empty($this->url->post('id'))) {
			$this->update();
		}
		else {
			$this->create();
		}
	}

	/**
	* Category index delete method
	* This method will be called on Category delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('category');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	protected function update() 
	{
		$data['id'] = $this->url->post('id');
		$data['name'] = $this->url->post('name');
		$data['parent'] = $this->url->post('parent');
		$data['slug'] = $this->url->post('slug');
		$data['icon'] = $this->url->post('icon');
		$result = $this->categoryModel->updateCategory($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Category updated successfully.');
		$this->url->redirect('category/edit&id='.$data['id']);
	}

	protected function create()
	{
		$data['name'] = $this->url->post('name');
		$data['parent'] = $this->url->post('parent');
		$data['slug'] = $this->url->post('slug');
		$data['icon'] = $this->url->post('icon');
		$result = $this->categoryModel->createCategory($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Category created successfully.');
		$this->url->redirect('category');
	}

	protected function delete()
	{
		$result = $this->categoryModel->deleteCategory($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Category deleted successfully.');
		$this->url->redirect('category');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['title'] = 'Category Name!';
		}

		if ($this->commons->validateText($this->url->post('slug'))) {
			$error_flag = true;
			$error['author'] = 'Slug!';
		}

		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}