<?php

/**
* Comment Controller
*/
class CommentController extends Controller
{
	/**
	* Private Comment model variable
	* This will be used for calling Comment model's function
	**/
	private $commentModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/* Intilize Comment model */
		$this->commentModel = new Comment();
	}
	/**
	* Comment index method
	* This method will be called on Comment list view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all Comments data from DB using Comment model 
		**/
		$data['result'] = $this->commentModel->allComments();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*Render Comments view*/
		$this->view->render('blog/comment_list.tpl', $data);
	}
	/**
	* Comment index edit method
	* This method will be called on Comment edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to Comment list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('comment');
		}
		/**
		* Call getComment method from Comment model to get data from DB for single Comment
		* If Comment does not exist then redirect it to Comment list view
		**/
		$comment = $this->commentModel->getComment($id);
		if (!$comment) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Comment does not exist in database!');
			$this->url->redirect('comment');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set Edit Comment page title */
		$data['page_title'] = 'Edit Comment';
		/* Set Comment data to array */
		$data['result'] =  $comment;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'comment/action';
		/*Render Comment edit view*/
		$this->view->render('blog/comment_form.tpl', $data);
	}

	/**
	* Comment index action method
	* This method will be called on Comment submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit']) && !empty($this->url->post('id'))) {
			$this->url->redirect('comment');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			$this->url->redirect('comment/edit&id='.$this->url->post('id'));
		}

		if ($this->commons->validateToken($this->url->post('_token'))){
				$this->url->redirect('comment/edit&id='.$this->url->post('id'));
		}

		$this->update();
	}
	/**
	* Comment index delete method
	* This method will be called on Comment delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('comment');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	/**
	* Coment Update function 
	* This method will be called on Coment submit/save view
	**/
	protected function update()
	{
		$data['id'] = $this->url->post('id');
		$data['content'] = $this->url->post('content');
		$data['status'] = $this->url->post('status');

		$this->commentModel->updateComment($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Comment updated successfully.');
		$this->url->redirect('comment/edit&id='.$data['id']);
	}

	protected function delete()
	{
		$result = $this->commentModel->deleteComment($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Comment deleted successfully.');
		$this->url->redirect('comment');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;

		if ($this->commons->validateText($this->url->post('content'))) {
			$error_flag = true;
			$error['content'] = 'Comment!';
		}
		
		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}