<?php

/**
* Department Controller
*/
class DepartmentController extends Controller
{
	/**
	* Private Department model variable
	* This will be used for calling Department model's function
	**/
	private $departmentModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize Department model*/
		$this->departmentModel = new Department();
	}
	/**
	* Department index method
	* This method will be called on department list view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all department value from Db using deparmtent model method 
		**/
		$departments = $this->departmentModel->allDepartments();
		/* Set department data in array to pass to view */
		$data['result'] = $departments;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*Render department list view*/
		$this->view->render('themeoption/department_list.tpl', $data);
	}
	/**
	* Department index add method
	* This method will be called on Department add
	**/
	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add Department';
		/* Set empty data to array */
		$data['result'] =  NULL;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'themeoption/department/action';
		/*Render Department add view*/
		$this->view->render('themeoption/department_form.tpl', $data);
	}
	/**
	* Department index edit method
	* This method will be called on department edit view
	**/
	public function indexEdit()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Check if id exist in url if not exist then redirect to department list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('themeoption/department');
		}
		/**
		* Call getDepartment method from Department model to get data from DB for single Department
		* If Department does not exist then redirect it to Department list view
		**/
		$department = $this->departmentModel->getDepartment($id);
		if (!$department) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Department does not exist in database!');
			$this->url->redirect('themeoption/department');
		}
		/* Set Edit Department page title */
		$data['page_title'] = 'Edit Department';
		/* Set Department data to array tpo pass to view */
		$data['result'] = $department;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'themeoption/department/action';
		/*Render Department edit view*/
		$this->view->render('themeoption/department_form.tpl', $data);
	}
	/**
	* Info index action method
	* This method will be called on Info submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('themeoption/department');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$error = $validate_field;
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('themeoption/department/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('themeoption/department/add');
			}
		}

		if ($this->commons->validateToken($this->url->post('_token'))){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('themeoption/department/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('themeoption/department/add');
			}
		}

		if (!empty($this->url->post('id'))) {
			$this->update();
		}
		else {
			$this->create();
		}
	}
	/**
	* BLog index delete method
	* This method will be called on Department delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id'))) {
			$this->url->redirect('themeoption/department');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	protected function update()
	{
		$data['id'] = $this->url->post('id');
		$data['name'] = $this->url->post('name');
		$data['description'] = $this->url->post('description');
		$data['icon'] = $this->url->post('icon');
		$data['status'] = $this->url->post('status');

		$this->departmentModel->updateDepartment($data);	
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Department updated successfully.');
		$this->url->redirect('themeoption/department/edit&id='.$data['id']);
	}

	protected function create()
	{
		$data['name'] = $this->url->post('name');
		$data['description'] = $this->url->post('description');
		$data['icon'] = $this->url->post('icon');
		$data['status'] = $this->url->post('status');

		if ($result = $this->departmentModel->createDepartment($data)) {
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Department created successfully.');
			$this->url->redirect('themeoption/department/edit&id='.$result);
		} else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Department does not created (Server Error).');
			$this->url->redirect('themeoption/department/add');
		}
	}
	
	protected function delete()
	{
		$result = $this->departmentModel->deleteDepartment($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Department deleted successfully.');
		$this->url->redirect('themeoption/department');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($name = $this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['name'] = 'Name!';
		}

		if ($description = $this->commons->validateText($this->url->post('description'))) {
			$error_flag = true;
			$error['description'] = 'Description!';
		}

		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}