<?php

/**
* Doctor Controller
*/
class DoctorController extends Controller
{
	/**
	* Private Doctor model variable
	* This will be used for calling Doctor model's function
	**/
	private $doctorModel;
	function __construct()
	{
		/*Call parent constructor*/
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize Doctor model*/
		$this->doctorModel = new Doctor();
	}
	/**
	* Doctor index method
	* This method will be called on doctor list view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all Doctor data from Db using Doctor Model method 
		**/
		$doctors = $this->doctorModel->allDoctors();
		$data['result'] = $doctors;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*Render Doctor list view*/
		$this->view->render('themeoption/doctor_list.tpl', $data);
	}

	/**
	* Doctor index add method
	* This method will be called on Department add
	**/
	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add Doctor';
		/* Set empty data to array */
		$data['result'] =  NULL;
		$data['time'] =  NULL;
		$data['about'] =  NULL;
		$data['social'] =  NULL;
		$data['weekly'] =  NULL;
		$data['national'] =  NULL;
		/* Set department in array */
		$data['departments'] = $this->doctorModel->getDepartmentByName();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'themeoption/doctor/action';
		/*Render Doctor add view*/
		$this->view->render('themeoption/doctor_form.tpl', $data);
	}
	/**
	* Doctor index edit method
	* This method will be called on doctor edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to Doctor list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('themeoption/doctor');
		}
		/**
		* Call getDoctor method from Blog model to get data from DB for single doctor
		* If Doctor does not exist then redirect it to doctor list view
		**/
		$doctor = $this->doctorModel->getDoctor($id);
		if (!$doctor) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Doctor does not exist in database!');
			$this->url->redirect('themeoption/doctor');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set Doctor edit view page title in array */
		$data['page_title'] = 'Edit Doctor';
		/* Set Doctor data in array */
		$data['result'] = $doctor;
		/* Set department in array */
		$data['departments'] = $this->doctorModel->getDepartmentByName();
		/* Set about doctor in array */
		$data['about'] = json_decode($doctor['about'], true);
		/* Set doctor time table in array */
		$data['time'] = json_decode($doctor['time'], true);
		/* Set doctor weekly holiday in array */
		$data['weekly'] = json_decode($doctor['weekly'], true);
		/* Set doctor national or other holiday in array */
		$data['national'] = json_decode($doctor['national'], true);
		/*Set doctor social value in array*/
		$data['social'] = json_decode($doctor['social'], true);
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'themeoption/doctor/action';
		/*Render Doctor edit view*/
		$this->view->render('themeoption/doctor_form.tpl', $data);
	}
	/**
	* Info index action method
	* This method will be called on Info submit/save view
	**/
	public function indexAction()
	{
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/

		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter/select valid '.implode(", ",$validate_field).'!');
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('themeoption/doctor/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('themeoption/doctor/add');
			}
		}

		if ($this->commons->validateToken($this->url->post('_token'))){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('themeoption/doctor/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('themeoption/doctor/add');
			}
		}

		if (!empty($this->url->post('id'))) {
			$this->update();
		} else {
			$this->create();
		}
	}

	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('themeoption/doctor');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	protected function update()
	{
		$data['id'] = $this->url->post('id');
		$data['name'] = $this->url->post('name');
		$data['email'] = $this->url->post('email');
		$data['picture'] = $this->url->post('doctor-picture');
		$data['mobile'] = $this->url->post('mobile');
		$data['about'] = json_encode(array(
			'position' => $this->url->post('position'),
			'degree' =>  $this->url->post('degree'),
			'specility' => $this->url->post('specility'),
			'experience' => $this->url->post('experience'),
			'awards' => $this->url->post('awards')
			)
		);

		$data['department'] = $this->url->post('department');
		$data['status'] = $this->url->post('status');

		$data['social'] = json_encode(array(
			'facebook' => $this->url->post('facebook'),
			'twitter' => $this->url->post('twitter'), 
			'google' => $this->url->post('google'), 
			'instagram' => $this->url->post('instagram')
			)
		);
		$data['time'] = json_encode(array(
			'st1' => $this->url->post('st1'), 
			'et1' => $this->url->post('et1'),
			'st2' => $this->url->post('st2'), 
			'et2' => $this->url->post('et2'),
			'slot' => $this->url->post('slot')
			)
		);
		$weekly_holiday = array();
		if (isset($_POST['weeklyList'])) {
			foreach ($_POST['weeklyList'] as $selected_option) {
				array_push($weekly_holiday, $selected_option); 
			}	
		}
		$data['weekly'] = json_encode($weekly_holiday);
		$data['national'] = json_encode($this->url->post('nationalList'));
		$data['appointment'] = $this->url->post('appointment');
		$data['priority'] = !empty($this->url->post('priority')) ? $this->url->post('priority') : 99999;
		$this->doctorModel->updateDoctor($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Doctor updated successfully.');

		$this->url->redirect('themeoption/doctor/edit&id='.$data['id']);
	}

	protected function create()
	{
		$data['name'] = $this->url->post('name');
		$data['email'] = $this->url->post('email');
		$data['picture'] = $this->url->post('doctor-picture');
		$data['mobile'] = $this->url->post('mobile');
		$data['about'] = json_encode(array(
			'position' => $this->url->post('position'),
			'degree' =>  $this->url->post('degree'),
			'specility' => $this->url->post('specility'),
			'experience' => $this->url->post('experience'),
			'awards' => $this->url->post('awards'))
		);

		$data['department'] = $this->url->post('department');
		$data['status'] = $this->url->post('status');

		$data['social'] = json_encode(array(
			'facebook' => $this->url->post('facebook'),
			'twitter' => $this->url->post('twitter'), 
			'google' => $this->url->post('google'), 
			'instagram' => $this->url->post('instagram')
			));
		$data['time'] = json_encode(array(
			'st1' => $this->url->post('st1'), 
			'et1' => $this->url->post('et1'),
			'st2' => $this->url->post('st2'), 
			'et2' => $this->url->post('et2'),
			'slot' => $this->url->post('slot')
			));
		$weekly_holiday = array();
		if (isset($_POST['weeklyList'])) {
			foreach ($_POST['weeklyList'] as $selected_option) {
				array_push($weekly_holiday, $selected_option); 
			}	
		}
		$data['weekly'] = json_encode($weekly_holiday);
		$data['national'] = json_encode($this->url->post('nationalList'));
		$data['appointment'] = $this->url->post('appointment');
		$data['priority'] = !empty($this->url->post('priority')) ? $this->url->post('priority') : 99999;
		
		if ($result = $this->doctorModel->createDoctor($data)) {
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Doctor created successfully.');
			$this->url->redirect('themeoption/doctor/edit&id='.$result);
		} else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Doctor does not created (Server Error).');
			$this->url->redirect('themeoption/doctor/add');
		}
	}

	protected function delete()
	{
		$result = $this->doctorModel->deleteDoctor($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Doctor deleted successfully.');
		$this->url->redirect('themeoption/doctor');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ( $this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['name'] = 'Please enter valid doctor name!';
		}

		if ($this->commons->validateEmail($this->url->post('email'))) {
			$error_flag = true;
			$error['email'] = 'Please enter valid email address!';
		}

		if ($this->commons->validatePhoneNumber($this->url->post('mobile'))) {
			$error_flag = true;
			$error['mobile'] = 'Please enter valid Mobile Number!';
		}

		if ($this->commons->validateNumeric($this->url->post('department'))) {
			$error_flag = true;
			$error['department'] = 'Please enter valid Mobile Number!';
		}

		if (!empty($this->url->post('facebook'))) {
			if ( $facebook = $this->commons->validateUrl($this->url->post('facebook')) ) {
				$error_flag = true;
				$error['facebook'] = 'Please enter valid facebook address!';
			}
		}
		
		if (!empty($this->url->post('twitter'))) {
			if ( $twitter = $this->commons->validateUrl($this->url->post('twitter')) ) {
				$error_flag = true;
				$error['twitter'] = 'Please enter valid twitter address!';
			}
		}
		if (!empty($this->url->post('google'))) {
			if ( $google = $this->commons->validateUrl($this->url->post('google')) ) {
				$error_flag = true;
				$error['google'] = 'Please enter valid google address!';
			}
		}
		if (!empty($this->url->post('instagram'))) {
			if ( $instagram = $this->commons->validateUrl($this->url->post('instagram')) ) {
				$error_flag = true;
				$error['instagram'] = 'Please enter valid instagram address!';
			}
		}

		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}