<?php

/**
* Facility Controller
*/
class FacilityController extends Controller
{
	/**
	* Private Facility model variable
	* This will be used for calling Facility model's function
	**/
	private $facilityModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize Facility model*/
		$this->facilityModel = new Facility();
	}
	/**
	* Facility index method
	* This method will be called on Facility list view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all Facilities from DB using facility model
		**/
		$facilities = $this->facilityModel->allFacilities();
		/* Set all Facilities data in array */
		$data['result'] = $facilities;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*Render facility list view*/
		$this->view->render('themeoption/facility_list.tpl', $data);
	}
	/**
	* Facility index add method
	* This method will be called on Facility add
	**/
	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add Facility';
		/* Set empty data to array */
		$data['result'] =  NULL;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'themeoption/facility/action';
		/*Render Blog add view*/
		$this->view->render('themeoption/facility_form.tpl', $data);
	}
	/**
	* Facility index edit method
	* This method will be called on Facility edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to Facility list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('themeoption/facility');
		}
		/**
		* Call getFacility method from Facility model to get data from DB for single Facility
		* If Facility does not exist then redirect it to Facility list view
		**/
		$facility = $this->facilityModel->getFacility($id);
		if (!$facility) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Facility does not exist in database!');
			$this->url->redirect('themeoption/facility');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set Facility edit apge title */
		$data['page_title'] = 'Edit Facility';
		/* Set Facility data in array to pass */
		$data['result'] = $facility;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'themeoption/facility/action';
		/*Render Facility edit view*/
		$this->view->render('themeoption/facility_form.tpl', $data);
	}
	/**
	* Info index action method
	* This method will be called on Info submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('request');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter/select valid '.implode(", ",$validate_field).'!');
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('themeoption/facility/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('themeoption/facility/add');
			}
		}

		if ( $this->commons->validateToken($this->url->post('_token')) ){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('themeoption/facility/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('themeoption/facility/add');
			}
		}

		if (!empty($this->url->post('id'))) {
			$this->update();
		} else {
			$this->create();
		}
	}
	/**
	* Facility index delete method
	* This method will be called on facility delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('themeoption/facility');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	protected function update()
	{
		$data['id'] = $this->url->post('id');
		$data['name'] = $this->url->post('name');
		$data['description'] = $this->url->post('description');
		$data['icon'] = $this->url->post('icon');
		$data['status'] = $this->url->post('status');

		$this->facilityModel->updateFacility($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Facility updated successfully.');
		$this->url->redirect('themeoption/facility/edit&id='.$data['id']);
	}

	protected function create()
	{
		$data['name'] = $this->url->post('name');
		$data['description'] = $this->url->post('description');
		$data['icon'] = $this->url->post('icon');
		$data['status'] = $this->url->post('status');

		if ($result = $this->facilityModel->createFacility($data)) {
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Facility created successfully.');
			$this->url->redirect('themeoption/facility/edit&id='.$result);
		} else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Facility does not created (Server Error).');
			$this->url->redirect('themeoption/facility/add');
		}
	}

	protected function delete()
	{
		$result = $this->facilityModel->deleteFacility($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Facility deleted successfully.');
		$this->url->redirect('themeoption/facility');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['name'] = 'Name!';
		}

		if ($this->commons->validateText($this->url->post('description'))) {
			$error_flag = true;
			$error['description'] = 'Description!';
		}

		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}