<?php

/**
* FinanceController
*/
class FinanceController extends Controller
{
	
	private $financeModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize appointment model*/
		$this->financeModel = new Finance();
	}

	public function currency()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();

		$data['result'] = $this->financeModel->getCurrency();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}

		$data['page_title'] = 'Currencies';
		$data['action'] = URL_ADMIN.DIR_ROUTE.'currency/action';
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		/*call appointment list view*/
		$this->view->render('finance/currency.tpl', $data);
	}

	public function currencyAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('currency');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			$this->url->redirect('currency');
		}
		if ($this->commons->validateToken($this->url->post('_token'))) {
			$this->url->redirect('currency');
		}

		if (!empty($this->url->post('id'))) {
			$result = $this->financeModel->updateCurrency($this->url->post);
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Currency updated successfully.');
			$this->url->redirect('currency');
		}
		else {
			$result = $this->financeModel->createCurrency($this->url->post);
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Currency created successfully.');
			$this->url->redirect('currency');
		}
	}

	public function currencyDelete()
	{
		$result = $this->financeModel->deleteCurrency($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Currency deleted successfully.');
		$this->url->redirect('currency');
	}


	public function paymentMethod()
	{
		
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all Tax data from DB using Tax model 
		**/
		$data['result'] = $this->financeModel->getPaymentMethod();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/* Set page title */
		$data['page_title'] = 'Payment Method';
		$data['action'] = URL_ADMIN.DIR_ROUTE.'paymentmethod/action';
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		
		/*Render User list view*/
		$this->view->render('finance/payment_method.tpl', $data);
	}

	public function paymentMethodAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('paymentmethod');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			$this->url->redirect('paymentmethod');
		}
		if ($this->commons->validateToken($this->url->post('_token'))) {
			$this->url->redirect('paymentmethod');
		}

		if (!empty($this->url->post('id'))) {
			$result = $this->financeModel->updatePaymentMethod($this->url->post);
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Payment Method updated successfully.');
			$this->url->redirect('paymentmethod');
		}
		else {
			$result = $this->financeModel->createPaymentMethod($this->url->post);
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Payment Method created successfully.');
			$this->url->redirect('paymentmethod');
		}
	}

	public function paymentMethodDelete()
	{
		$result = $this->financeModel->deletePaymentMethod($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Payment Method deleted successfully.');
		$this->url->redirect('paymentmethod');
	}

	public function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['title'] = 'Name!';
		}
		
		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}

	/**
	* Contact index method
	* This method will be called on Contact list view
	**/
	public function tax()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all Tax data from DB using Tax model 
		**/
		$data['result'] = $this->financeModel->getTaxes();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/* Set page title */
		$data['page_title'] = 'Tax Rates';
		$data['action'] = URL_ADMIN.DIR_ROUTE.'tax/action';
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		
		/*Render User list view*/
		$this->view->render('finance/tax.tpl', $data);
	}

	public function taxAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('tax');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateTaxField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			$this->url->redirect('tax');
		}

		if ($this->commons->validateToken($this->url->post('_token'))) {
			$this->url->redirect('tax');
		}

		if (!empty($this->url->post('id'))) {
			$result = $this->financeModel->updateTax($this->url->post);
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Tax Rate updated successfully.');
			$this->url->redirect('tax');
		}
		else {
			$result = $this->financeModel->createTax($this->url->post);
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Tax Rate created successfully.');
			$this->url->redirect('tax');
		}
	}

	public function taxDelete()
	{

		$result = $this->financeModel->deleteTax($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Tax Rate deleted successfully.');
		$this->url->redirect('tax');
	}

	public function validateTaxField()
	{
		$error = [];
		$error_flag = false;
		if ($this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['title'] = 'Tax Name!';
		}

		if ($this->commons->validateNumeric($this->url->post('rate'))) {
			$error_flag = true;
			$error['author'] = 'Tax Rate!';
		}
		
		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}