<?php

/**
* Info Controller
*/
class InfoController extends Controller
{
	/**
	* Private Info model variable
	* This will be used for calling Info model's function
	**/
	private $infoModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize info model*/
		$this->infoModel = new Info();
	}
	/**
	* Info index edit method
	* This method will be called on Info edit view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all info data from DB using info model's method
		**/
		$info_data = $this->infoModel->getInfo();
		/* Set all info data to array to pass to view */
		$data['result'] = $info_data;
		/* Set doctor time data to array to pass to view */
		$data['timetable'] = json_decode($info_data['timing'], true);
		/* Set social data to array to pass to view */
		$data['social'] = json_decode($info_data['social'], true);
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		/*Set action method for form submit call*/
		$data['action'] = URL_ADMIN.DIR_ROUTE.'info/action';
		/*Render Info view*/
		$this->view->render('info/info.tpl', $data);
	}
	/**
	* Info index action method
	* This method will be called on Info submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('info');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			$this->url->redirect('info');
		}

		if ($this->commons->validateToken($this->url->post('_token'))){
			$this->url->redirect('info');
		}

		$this->update();
	}

	protected function update()
	{
		/**
		* Get all form data in array 
		**/
		$data['url'] = $this->url->post('url');
		$data['mode'] = $this->url->post('mode');
		$data['name'] = $this->url->post('name');
		$data['logo'] = $this->url->post('logo');
		$data['favicon'] = $this->url->post('favicon');
		$data['color'] = (null !== $this->url->post('theme-color')) ? $this->url->post('theme-color') : 'blue';
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['address'] = $this->url->post('address');
		$data['language'] = $this->url->post('language');
		$data['emergency'] = $this->url->post('emergency');
		$data['currency'] = $this->url->post('currency');
		/*Set Social link in json string*/
		$data['social'] = json_encode(array(
			"facebook" => $this->url->post('facebook'),
			"twitter" => $this->url->post('twitter'),
			"google" => $this->url->post('google'),
			"instagram" => $this->url->post('instagram'),
			"youtube" => $this->url->post('youtube'),
			"linkedin" => $this->url->post('linkedin'),
			"flickr" => $this->url->post('flickr'),
			"rss" => $this->url->post('rss')));
		/*Set Time Table in json string*/
		$data['timetable'] = json_encode( array(
			"sun" => $this->url->post('sun'),
			"mon" => $this->url->post('mon'),
			"tue" => $this->url->post('tue'),
			"wed" => $this->url->post('wed'),
			"thu" => $this->url->post('thu'),
			"fri" => $this->url->post('fri'),
			"sat" => $this->url->post('sat')) );
	
		$result = $this->infoModel->updateInfo($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Clinic Info updated successfully.');
		$this->url->redirect('info');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($this->commons->validateUrl($this->url->post('url'))) {
			$error_flag = true;
			$error['url'] = 'URL';
		}

		if ($this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['name'] = 'Name';
		}

		if ($this->commons->validateEmail($this->url->post('email'))) {
			$error_flag = true;
			$error['email'] = 'Email Address';
		}

		if ($this->commons->validateText($this->url->post('mobile'))) {
			$error_flag = true;
			$error['mobile'] = 'mobile number';
		}

		if ($this->commons->validateText($this->url->post('emergency'))) {
			$error_flag = true;
			$error['emergency'] = 'Emergency Number';
		}

		if ($this->commons->validateText($this->url->post('currency'))) {
			$error_flag = true;
			$error['currency'] = 'Currency Code';
		}

		if (!empty($this->url->post('facebook'))) {
			if ($this->commons->validateUrl($this->url->post('facebook'))) {
				$error_flag = true;
				$error['facebook'] = 'Facebook address!';
			}
		}

		if (!empty($this->url->post('twitter'))) {
			if ($this->commons->validateUrl($this->url->post('twitter'))) {
				$error_flag = true;
				$error['twitter'] = 'Twitter address!';
			}
		}
		if (!empty($this->url->post('google'))) {
			if ($this->commons->validateUrl($this->url->post('google'))) {
				$error_flag = true;
				$error['google'] = 'Google address!';
			}
		}
		if (!empty($this->url->post('instagram'))) {
			if ($this->commons->validateUrl($this->url->post('instagram'))) {
				$error_flag = true;
				$error['instagram'] = 'Instagram address!';
			}
		}

		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}