<?php

/**
* Invoice Controller
*/
class InvoiceController extends Controller
{
	/**
	* Private Invoice model variable
	* This will be used for calling Invoice model's function
	**/
	private $invoiceModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/* Intilize Invoice model */
		$this->invoiceModel = new Invoice();
	}
	/**
	* Invoice index edit method
	* This method will be called on Invoice list view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all blogs data from DB using blog model 
		**/
		
		$data['result'] = $this->invoiceModel->allInvoices();
		$data['doctors'] = $this->invoiceModel->getDoctors();
		$this->commons = new Commons();
		$data['currency'] = $this->commons->getCurrencyCode();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*Render Invoice list view*/
		$this->view->render('invoice/invoice_list.tpl', $data);
	}

	public function indexView()
	{
		/**
		* Check if id exist in url if not exist then redirect to blog list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('invoice');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		
		/**
		* Call getInvoice method from invoice model to get data from DB for single blog
		* If blog does not exist then redirect it to invoice list view
		**/
		$data['result'] = $this->invoiceModel->getInvoiceView($id);
		if (!$data['result']) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Invoice does not exist in database!');
			$this->url->redirect('invoice');
		}

		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$this->commons = new Commons();
		$data['info'] = $this->commons->getInvoiceBasics();
		$data['page_title'] = 'Invoice View';
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);

		/*Render Invoice list view*/
		$this->view->render('invoice/invoice_view.tpl', $data);
	}

	public function indexPrint()
	{
		/**
		* Check if id exist in url if not exist then redirect to blog list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('invoice');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		
		/**
		* Call getInvoice method from invoice model to get data from DB for single blog
		* If blog does not exist then redirect it to invoice list view
		**/
		$data['result'] = $this->invoiceModel->getInvoiceView($id);
		if (!$data['result']) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Invoice does not exist in database!');
			$this->url->redirect('invoice');
		}

		$this->commons = new Commons();
		$data['info'] = $this->commons->getInvoiceBasics();
		$data['page_title'] = 'Invoice View';

		/*Render Invoice list view*/
		$this->view->render('invoice/invoice_print.tpl', $data);
	}

	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		
		$data['doctors'] = $this->invoiceModel->getDoctors();
		$data['currency'] = $this->invoiceModel->getCurrency();
		$data['payment_method'] = $this->invoiceModel->getPaymentMethod();
		$data['taxes'] = $this->invoiceModel->getTaxes();

		if ($this->url->get('id')) {
			$result = $this->invoiceModel->getAppointmentData($this->url->get('id'));
			$data['result']['items'] = NULL;
			$data['result']['id'] = NULL;
			$data['result']['paiddate'] = NULL;
			$data['result']['duedate'] = NULL;
			$data['result']['date_of_joining'] = NULL;
			$data['result']['currency'] = NULL;
			$data['result']['method'] = NULL;
			$data['result']['status'] = NULL;
			$data['result']['due'] = NULL;
			$data['result']['paid'] = NULL;
			$data['result']['amount'] = NULL;
			$data['result']['subtotal'] = NULL;
			$data['result']['tax'] = NULL;
			$data['result']['discounttype'] = NULL;
			$data['result']['discount'] = NULL;
			$data['result']['discount_value'] = NULL;
			$data['result']['note'] = NULL;
			$data['result']['tc'] = NULL;
			$data['result']['name'] = $result['name'];
			$data['result']['email'] = $result['email'];
			$data['result']['mobile'] = $result['mobile'];
			$data['result']['doctor'] = $result['doctor'];
			$data['result']['appointment_id'] = $result['appointment_id'];
			$data['result']['doctor_id'] = $result['doctor_id'];
		}
		else {
			$data['result'] =  NULL;
		}

		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['page_title'] = 'Invoice Edit';
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'invoice/action';
		$this->view->render('invoice/invoice_form.tpl', $data);
	}
	
	/**
	* Invoice index edit method
	* This method will be called on invoice edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to blog list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('invoice');
		}
		/**
		* Call getInvoice method from invoice model to get data from DB for single blog
		* If blog does not exist then redirect it to invoice list view
		**/
		$invoice = $this->invoiceModel->getInvoice($id);
		if (!$invoice) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Invoice does not exist in database!');
			$this->url->redirect('invoice');
		}

		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		
		
		$data['doctors'] = $this->invoiceModel->getDoctors();
		$data['currency'] = $this->invoiceModel->getCurrency();
		$data['payment_method'] = $this->invoiceModel->getPaymentMethod();
		$data['taxes'] = $this->invoiceModel->getTaxes();
		/* Set Blog data to array */
		
		$data['result'] =  $invoice;
		$data['result']['items'] = json_decode($invoice['item'], true);

		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'invoice/action';
		/*Render invoice edit view*/
		$this->view->render('invoice/invoice_form.tpl', $data);
	}

	public function indexSentMail()
	{
		$data = $this->url->post('mail');

		if ($validate_field = $this->vaildateMailField($data)) {
			$this->session->data['message'] = array('alert' => 'error', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			$this->url->redirect('invoice/view&id='.$data['invoice']);
		}

		if ($this->commons->validateToken($this->url->post('_token'))) {
			$this->url->redirect('invoice/view&id='.$data['invoice']);
		}
		
		$mailer = new Mailer();
		$mailer->mail->setFrom(SITEEMAIL, NAME);
		$mailer->mail->addAddress($data['to'], $data['name']);
		if (!empty($data['bcc'])) {
			$mailer->mail->addBCC($data['bcc'], $data['bcc']);
		}
		$mailer->mail->isHTML(true);
		$mailer->mail->Subject = $data['subject'];
		$mailer->mail->Body = html_entity_decode($data['message']);
		$mailer->mail->AltBody = 'Hello Dear,
		Your Invoice has been created. Invoice Number - INV-'.str_pad($data['invoice'], 4, '0', STR_PAD_LEFT).'
		You can also view this invoice online by clicking here.
		Thank you,
		Administrator';

		$mailer->sendMail();
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Email Sent successfully.');
		$this->url->redirect('invoice/view&id='.$data['invoice']);
	}

	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('invoice');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($this->commons->validateToken($this->url->post('_token'))){
			if (!empty($this->url->post('invoice-id'))) {
				$this->url->redirect('invoice/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('invoice/add');
			}
		}

		if (!empty($this->url->post('id'))) {
			$this->update();
		}
		else {
			$this->create();
		}
	}

	/**
	* invoice index delete method
	* This method will be called on blog delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('invoice');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	protected function update()
	{
		$data = $this->url->post('invoice');
		$data['id'] = $this->url->post('id');
		$data['item'] = json_encode($data['item']);
		$data['duedate'] = date_format(date_create($data['duedate']), 'Y-m-d');
		$data['paiddate'] = date_format(date_create($data['paiddate']), 'Y-m-d');

		$this->invoiceModel->updateInvoice($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Invoice updated successfully.');
		$this->url->redirect('invoice/view&id='.$data['id']);
	}

	public function create()
	{
		$data = $this->url->post('invoice');
		$data['item'] = json_encode($data['item']);
		$data['duedate'] = date_format(date_create($data['duedate']), 'Y-m-d');
		$data['paiddate'] = date_format(date_create($data['paiddate']), 'Y-m-d');

		$result = $this->invoiceModel->createInvoice($data);
		
		if ((int)$result && $data['appointment_id']) {
			$this->invoiceModel->updateInvoiceIdAppointment($result, $data['appointment_id']);
			$this->invoiceMail($result);
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Invoice created successfully.');
			$this->url->redirect('invoice/view&id='.$result);
		} elseif ( (int)$result ) {
			$this->invoiceMail($result);
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Invoice created successfully.');
			$this->url->redirect('invoice/view&id='.$result);
		} else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Invoice does not created (Server Error).');
			$this->url->redirect('invoice/add');
		}
	}

	private function invoiceMail($id)
	{
		$data = $this->invoiceModel->getInvoiceView($id);

		$message = file_get_contents(DIR_APP.'views/mail_template/create-invoice.tpl');
		$message = str_replace('{name}', $data['name'], $message);
		$message = str_replace('{invoiceId}', $data['id'], $message);
		$message = str_replace('{doctor}', $data['doctor'], $message);
		$message = str_replace('{date}', $data['duedate'], $message);
		$message = str_replace('{total}', $data['abbr'].$data['amount'], $message);
		$message = str_replace('{paid}', $data['abbr'].$data['paid'], $message);
		$message = str_replace('{due}', $data['abbr'].$data['due'], $message);
		$message = str_replace('{address}', ADDRESS, $message);
		$message = str_replace('{site_name}', NAME, $message);
		$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
		$mailer = new Mailer();
		$mailer->mail->setFrom(SITEEMAIL, NAME);
		$mailer->mail->addAddress($data['email'], $data['name']);
		$mailer->mail->isHTML(true);
		$mailer->mail->Subject = 'Invoice Generated by '.NAME;
		$mailer->mail->Body = $message;

		$mailer->mail->AltBody = 'Hello '.$data['name'].'.
		Your invoice has been generated by '.NAME.'. Thanks for using our services and we are happy to serve you again.'.PHP_EOL.' Login into your account to download full invoice';
		$mailer->sendMail();
	}

	protected function delete()
	{
		$result = $this->invoiceModel->deleteInvoice($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Invoice deleted successfully.');
		$this->url->redirect('invoice');
	}
	/**
	* Validate Field Method
	* This method will be called on to validate invoice field
	**/
	private function vaildateMailField($data)
	{
		$error = [];
		$error_flag = false;

		if ($this->commons->validateText($data['to'])) {
			$error_flag = true;
			$error['to'] = 'Email!';
		}

		if ($this->commons->validateText($data['subject'])) {
			$error_flag = true;
			$error['subject'] = 'Subject!';
		}

		if ($this->commons->validateText($data['message'])) {
			$error_flag = true;
			$error['message'] = 'Message!';
		}
		
		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}