<?php

/**
* Login Controller
*/
class LoginController extends Controller
{
	private $common;
	function __construct()
	{
		parent::__construct();
		/**
		* Check if user is logged in or not
		* If logged in then get user basic info from DB
		**/
		$this->commons = new CommonsController();
		$this->common = new Common();
	}

	public function index()
	{
		if ($this->common->isLoggedIn()) {
			$this->url->redirect('dashboard');
		}
		$this->getPage();
	}

	protected function getPage()
	{
		$data['error'] = '';
		if (isset($this->session->data['error'])) {
			$data['error'] = $this->session->data['error'];
			unset($this->session->data['error']);
		}

		if (isset($_SERVER['HTTP_REFERER']) && !empty($_SERVER['HTTP_REFERER'])) {
			$this->session->data['refferal'] = $_SERVER['HTTP_REFERER'];
		}

		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'login';
		$this->view->render('auth/login.tpl', $data);
	}

	public function login()
	{
		
		if ($this->common->isLoggedIn()) {
			$this->url->redirect('dashboard');
		}
		if ($this->commons->validateToken($this->url->post('_token'))){
			$this->url->redirect('login');
		}

		$username = $this->url->post('username');
		$password = $this->url->post('password');

		if (!$this->validate($username, $password)) {
			$this->session->data['error'] = 'Warning: Please enter valid data in input box.';
			$this->url->redirect('login');
		}

		unset($this->session->data['user_id']);
		unset($this->session->data['login_token']);
		unset($this->session->data['role']);

		/*Intiate login Model*/
		$this->loginModel = new Login();
		/** 
		* If the user exists
		* Check his account and login attempts
		* Get user data 
        **/
		if ($user = $this->loginModel->checkUser($username)) {
			/** 
			* User exists now We check if
			* The account is locked From too many login attempts 
            **/
			if (!$this->checkLoginAttempts($user['email'])) {
				$this->session->data['error'] = 'Warning: Your account has exceeded allowed number of login attempts. Please try again in 1 hour.';
				$this->url->redirect('login');
			}
			else if ($user['status'] === 1) {
	            /** 
	            * Check if the password in the database matches the password user submitted.
	            * We are using the password_verify function to avoid timing attacks.
	            **/
	            if (password_verify( $password, $user['password'])) {
	            	$this->loginModel->deleteAttempt($user['email']);
	            	/** 
	            	* Start session for user create session varible 
		            * Create session login string for authentication
		            **/
	            	$this->session->data['user_id'] = preg_replace("/[^0-9]+/", "", $user['user_id']); 
	            	$this->session->data['role'] = preg_replace("/[^0-9]+/", "", $user['user_role']);
	            	$this->session->data['login_token'] = hash('sha512', AUTH_KEY . LOGGED_IN_SALT);
	            	$this->url->Redirect('dashboard');
	            } else {
	            	/** 
	            	* Add login attemt to Db
		            * Redirect back to login page and set error for user
		            **/
	            	$this->loginModel->addAttempt($user['email']);
	            	$this->session->data['error'] = 'Warning: No match for Username and/or Password.';
	            	$this->url->Redirect('login');
	            }
	        }
	        else {
	        	/** 
	        	* If account is disabled by admin 
		        * Then Show error to user
		        **/
	        	$this->session->data['error'] = 'Warning: Your account has disabled for more info contact us.';
	        	$this->url->redirect('login');
	        }
	    }
	    else {
	    	/** 
	        * If email address not found in DB 
		    * Show error to user for creating account
		    **/
	    	$this->session->data['error'] = 'Warning: No match for Username and/or Password.';
	    	$this->url->redirect('login');
	    }
	}

	public function logout()
	{
		$this->session->destroy();
		$this->url->redirect('login');
	}

	/**
	* Validate login credentials on server side
	* Validation is also done on client side (Using html5 and javascripts)
	**/
	protected function validate($email, $password) 
	{
		/** 
		* Check if email and password contains valid phrases
		**/
		if (strlen($email) < 4 ) {
			/** 
			* If email is not valid
			* Return false
			**/
			return false;
		}
		elseif (strlen($password) < 6) {
			/** 
			* If password is not valid or minimum 6 character
			* Return false
			**/
			return false;
		}
		else {
			return true;
		}
	}

	/** 
	* Check login attempts of user for brute force attacks 
	**/
	protected function checkLoginAttempts($email)
	{
		/**
		* Get attempts from DB and check with predefined field
		* All login attempts are counted from the past 1 hours. 
		**/
		$login_attempts = $this->loginModel->checkAttempts($email);
		if ($login_attempts && ($login_attempts['count'] >= 4) && strtotime('-1 hour') < strtotime($login_attempts['date_modified'])) {
			return false;
		}
		else {
			return true;
		}
	}
}