<?php

/**
* Blog Controller
*/
class PharmacyController extends Controller
{
	/**
	* Private Blog model variable
	* This will be used for calling Pharmacy model's function
	**/
	private $pharmacyModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/* Intilize Blog model */
		$this->pharmacyModel = new Pharmacy();
	}
	/**
	* Blog index edit method
	* This method will be called on Pharmacy list view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all Pharmacy data from DB using Pharmacy model 
		**/
		$data['result'] = $this->pharmacyModel->allPharmacy();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*Render Blog view*/
		$this->view->render('pharmacy/pharmacy_list.tpl', $data);
	}
	/**
	* Blog index add method
	* This method will be called on Blog add
	**/
	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add Medicine';
		/* Set empty data to array */
		$data['result'] =  NULL;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'pharmacy/action';
		/*Render Blog add view*/
		$this->view->render('pharmacy/pharmacy_form.tpl', $data);
	}
	/**
	* Blog index edit method
	* This method will be called on Blog edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to Pharmacy list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('pharmacy');
		}
		/**
		* Call getBlog method from Blog model to get data from DB for single Pharmacy
		* If Medicine does not exist then redirect it to Pharmacy list view
		**/
		$medicine = $this->pharmacyModel->getMedicine($id);
		if (!$medicine) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Medicine does not exist in database!');
			$this->url->redirect('pharmacy');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set Edit Pharmacy page title */
		$data['page_title'] = 'Edit Medicine';
		/* Set Blog data to array */
		$data['result'] =  $medicine;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'pharmacy/action';
		/*Render Blog edit view*/
		$this->view->render('pharmacy/pharmacy_form.tpl', $data);
	}

	/**
	* Blog index action method
	* This method will be called on Pharmacy submit/save view
	**/
	public function indexAction()
	{

		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('pharmacy');
			exit();
		}

		if ($this->commons->validateToken($this->url->post('_token'))){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('pharmacy/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('pharmacy/add');
			}
		}

		if (!empty($this->url->post('id'))) {
			$this->update();
		}
		else {
			$this->create();
		}
	}
	/**
	* Blog index delete method
	* This method will be called on Pharmacy delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('pharmacy');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	public function getPrescription()
	{
		if (empty($this->url->get('id'))) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Prescription does not exist in database!');
			$this->url->redirect('appointment');
		}
		$data['info'] = $this->pharmacyModel->getInfo();
		
		$data['result'] = $this->pharmacyModel->prescriptionPharmacy($this->url->get('id'));
		$data['degree'] = json_decode($data['result']['about'], true)['degree'];
		$data['specility'] = json_decode($data['result']['about'], true)['specility'];
		$this->view->render('pharmacy/prescription.tpl', $data);
	}

	/**
	* Blog Update function 
	* This method will be called on Pharmacy submit/save view
	**/
	protected function update()
	{
		$data = $this->url->post;
		$this->pharmacyModel->updateMedicine($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Medicine updated successfully.');
		
		$this->url->redirect('pharmacy/edit&id='.$data['id']);
	}

	protected function create()
	{
		$data = $this->url->post;
		if ($result = $this->pharmacyModel->createMedicine($data)) {
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Medicine created successfully.');
			$this->url->redirect('pharmacy/edit&id='.$result);
		} else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Medicine does not created (Server Error).');
			$this->url->redirect('pharmacy/add');
		}
	}

	protected function delete()
	{
		$result = $this->pharmacyModel->deleteMedicine($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Medicine deleted successfully.');
		$this->url->redirect('pharmacy');
	}
}