<?php

/**
* Request Controller
*/
class RequestController extends Controller
{
	/**
	* Private Request model variable
	* This will be used for calling Request model's function
	**/
	private $requestModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize Request model*/
		$this->requestModel = new Userrequest();
	}
	/**
	* Request index method
	* This method will be called on Request list view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all request and store in array
		* That array will be passed on to view
		**/
		$data['result'] = $this->requestModel->allRequests();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*Render Request list view*/
		$this->view->render('request/request_list.tpl', $data);
	}
	/**
	* Request index add method
	* This method will be called on Request add
	**/
	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add Request';
		/* Set empty data to array */
		$data['result'] =  NULL;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'request/action';
		/*Render Blog add view*/
		$this->view->render('request/request_form.tpl', $data);
	}
	/**
	* Request index edit method
	* This method will be called on Request edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to reuqest list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('request');
		}
		/**
		* Call getRequest method from Request model to get data from DB for single Request
		* If reuqest does not exist then redirect it to reuqest list view
		**/
		$request = $this->requestModel->getRequest($id);
		if (!$request) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Request does not exist in database!');
			$this->url->redirect('request');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set reuest data to array to pass to view */
		$data['page_title'] = 'EDIT REQUEST';
		$data['result'] = $request;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'request/action';
		/*Render Request edit view*/
		$this->view->render('request/request_form.tpl', $data);
	}
	/**
	* Info index action method
	* This method will be called on Info submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('request');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('request/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('request/add');
			}
		}
		
		if ( $this->commons->validateToken($this->url->post('_token')) ){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('request/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('request/add');
			}
		}
		
		if (!empty($this->url->post('id'))) {
			$this->update();
		} else {
			$this->create();
		}
	}
	/**
	* Request index delete method
	* This method will be called on Request delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('request');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	protected function update()
	{
		$data['id'] = $this->url->post('id');
		$data['name'] = $this->url->post('name');
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['subject'] = $this->url->post('subject');
		$data['message'] = $this->url->post('message');
		$data['remark'] = $this->url->post('remark');
		$data['status'] = $this->url->post('status');

		$this->requestModel->updateRequest($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Request updated successfully.');
		$message = file_get_contents(DIR_APP.'views/mail_template/update-request.tpl');
		$message = str_replace('{name}', $data['name'], $message);
		$message = str_replace('{subject}', $data['subject'], $message);
		$message = str_replace('{message}', $data['message'], $message);
		$message = str_replace('{remark}', $data['remark'], $message);
		$message = str_replace('{site_name}', NAME, $message);
		$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
		$mailer = new Mailer();
		$mailer->mail->setFrom(SITEEMAIL, NAME);
		$mailer->mail->addAddress($data['email'], $data['name']);
		$mailer->mail->isHTML(true);
		$mailer->mail->Subject = 'Your Request updated at '.NAME;
		$mailer->mail->Body = $message;
		$mailer->mail->AltBody = 'Hello '.$data['name'].'.
		Your request has been updated.'.PHP_EOL.'
		Subject :  '.$data['subject'].'.
		Message :  '.$data['message'];
		$mailer->sendMail();
		$this->url->redirect('request/edit&id='.$data['id']);
	}
	/**
	* Request Create method
	* This method will be called on Request create
	* Get all data in one array and call @requestModal to store data in DB
	**/
	protected function create()
	{
		$data['name'] = $this->url->post('name');
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['subject'] = $this->url->post('subject');
		$data['message'] = $this->url->post('message');
		$data['remark'] = $this->url->post('remark');
		$result = $this->requestModel->createRequest($data);
		if ($result) {
			$message = file_get_contents(DIR_APP.'views/mail_template/create-request.tpl');
			$message = str_replace('{name}', $data['name'], $message);
			$message = str_replace('{email}', $data['email'], $message);
			$message = str_replace('{mobile}', $data['mobile'], $message);
			$message = str_replace('{subject}', $data['subject'], $message);
			$message = str_replace('{message}', $data['message'], $message);
			$message = str_replace('{site_name}', NAME, $message);
			$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
			$mailer = new Mailer();
			$mailer->mail->setFrom(SITEEMAIL, NAME);
			$mailer->mail->addAddress($data['email'], $data['name']);
			$mailer->mail->isHTML(true);
			$mailer->mail->Subject = 'Request created at '.NAME;
			$mailer->mail->Body = $message;
			$mailer->mail->AltBody = 'Hello '.$data['name'].'.
			Your request has been recieved.'.PHP_EOL.'
			Subject :  '.$data['subject'].'.
			Message :  '.$data['message'];
			$mailer->sendMail();
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Request created successfully.');
			$this->url->redirect('request/edit&id='.$result);
		} else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Request does not created (Server Error).');
			$this->url->redirect('request/add');
		}
	}

	protected function delete()
	{
		$result = $this->requestModel->deleteRequest($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Request deleted successfully.');
		$this->url->redirect('request');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($name = $this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['name'] = 'Name';
		}

		if ($email = $this->commons->validateEmail($this->url->post('email'))) {
			$error_flag = true;
			$error['email'] = 'Email Address';
		}

		if ($mobile = $this->commons->validatePhoneNumber($this->url->post('mobile'))) {
			$error_flag = true;
			$error['mobile'] = 'Mobile Number';
		}

		if ($subject = $this->commons->validateText($this->url->post('subject'))) {
			$error_flag = true;
			$error['subject'] = 'Subject';
		}
		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}