<?php

/**
* Review Controller
*/
class ReviewController extends Controller
{
	private $reviewModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize appointment model*/
		$this->reviewModel = new Review();	
	}

	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all blogs data from DB using blog model 
		**/
		$data['result'] = $this->reviewModel->allReviews();
		
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*Render Blog view*/
		$this->view->render('review/review_list.tpl', $data);
	}

	/**
	* Review index edit method
	* This method will be called on Review edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to Review list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('blog');
		}
		/**
		* Call getReview method from Blog model to get data from DB for single Review
		* If Review does not exist then redirect it to Review list view
		**/
		$review = $this->reviewModel->getReview($id);
		if (!$review) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Review does not exist in database!');
			$this->url->redirect('review');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set Edit blog page title */
		$data['page_title'] = 'Edit Review';
		/* Set Blog data to array */
		$data['result'] =  $review;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'review/action';
		/*Render Blog edit view*/
		$this->view->render('review/review_form.tpl', $data);
	}
	/**
	* Review index action method
	* This method will be called on review submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit']) && !empty($this->url->post('id'))) {
			$this->url->redirect('review');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			$this->url->redirect('review/edit&id='.$this->url->post('id'));
		}

		if ($this->commons->validateToken($this->url->post('_token'))){
				$this->url->redirect('review/edit&id='.$this->url->post('id'));
		}

		$this->update();
	}
	/**
	* Review index delete method
	* This method will be called on Review delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('review');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	/**
	* Review Update function 
	* This method will be called on Review submit/save view
	**/
	protected function update()
	{
		$data['id'] = $this->url->post('id');
		$data['content'] = $this->url->post('content');
		$data['status'] = $this->url->post('status');

		$this->reviewModel->updateReview($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Review updated successfully.');
		$this->url->redirect('review/edit&id='.$data['id']);
	}

	protected function delete()
	{
		$result = $this->reviewModel->deleteReview($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Review deleted successfully.');
		$this->url->redirect('review');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;

		if ($this->commons->validateText($this->url->post('content'))) {
			$error_flag = true;
			$error['content'] = 'Comment!';
		}
		
		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}