<?php

/**
* Service Controller
*/
class ServiceController extends Controller
{
	/**
	* Private Service model variable
	* This will be used for calling Service model's function
	**/
	private $serviceModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize Service model*/
		$this->serviceModel = new Service();
	}
	/**
	* Service index edit method
	* This method will be called on Service edit view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all Services 
		**/
		$data['result'] = $this->serviceModel->allServices();;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*call Service list view*/
		$this->view->render('themeoption/service_list.tpl', $data);
	}
	/**
	* Service index add method
	* This method will be called on Blog add
	**/
	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add Service';
		/* Set empty data to array */
		$data['result'] =  NULL;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'themeoption/service/action';
		/*Render Service add view*/
		$this->view->render('themeoption/service_form.tpl', $data);
	}
	/**
	* Service index edit method
	* This method will be called on Service edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to Service list view 
		**/		
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('themeoption/service');
		}
		/**
		* Call getService method from Service model to get data from DB for single Service
		* If Service does not exist then redirect it to Service list view
		**/
		$service = $this->serviceModel->getService($id);
		if (!$service) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Service does not exist in database!');
			$this->url->redirect('themeoption/service');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set Edit Service page title */
		$data['page_title'] = 'Edit Service';
		/* Set Service data to array */
		$data['result'] = $service;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'themeoption/service/action';
		/*Render Service edit view*/
		$this->view->render('themeoption/service_form.tpl', $data);
	}
	/**
	* Info index action method
	* This method will be called on Info submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('themeoption/service');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('themeoption/service/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('themeoption/service/add');
			}
		}
		
		if ($this->commons->validateToken($this->url->post('_token'))){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('themeoption/service/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('themeoption/service/add');
			}
		}
		
		if (!empty($this->url->post('id'))) {
			$this->update();
		} else {
			$this->create();
		}
	}
	/**
	* Facility index delete method
	* This method will be called on blog delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('themeoption/service');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	protected function update()
	{
		$data['id'] = $this->url->post('id');
		$data['name'] = $this->url->post('name');
		$data['picture'] = $this->url->post('picture');
		$data['short_post'] = $this->url->post('short_post');
		$data['long_post'] = $this->url->post('long_post');
		$data['icon'] = $this->url->post('icon');
		$data['status'] = $this->url->post('status');
		$data['priority'] = !empty($this->url->post('priority')) ? $this->url->post('priority') : 99999;

		$this->serviceModel->updateService($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Service updated successfully.');
		$this->url->redirect('themeoption/service/edit&id='.$data['id']);
	}

	protected function create()
	{
		$data['name'] = $this->url->post('name');
		$data['picture'] = $this->url->post('picture');
		$data['short_post'] = $this->url->post('short_post');
		$data['long_post'] = $this->url->post('long_post');
		$data['icon'] = $this->url->post('icon');
		$data['status'] = $this->url->post('status');
		$data['priority'] = !empty($this->url->post('priority')) ? $this->url->post('priority') : 99999;

		if ($result = $this->serviceModel->createService($data)) {
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Service created successfully.');
			$this->url->redirect('themeoption/service/edit&id='.$result);
		}
		else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Service does not created (Server Error).');
			$this->url->redirect('themeoption/service/add');
		}
	}

	protected function delete()
	{
		$result = $this->serviceModel->deleteService($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Service deleted successfully.');
		$this->url->redirect('themeoption/service');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($name = $this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['name'] = 'Name';
		}

		if ($description = $this->commons->validateText($this->url->post('short_post'))) {
			$error_flag = true;
			$error['short_post'] = 'Short Description';
		}

		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}