<?php

/**
* Setting Controller
*/
class SettingController extends Controller
{
	/**
	* Private Setting model variable
	* This will be used for calling Setting model's function
	**/
	private $settingModel;
	/* Private Setting name variable */
	private $setting_name;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize Setting model*/
		$this->settingModel = new Setting();
		/* Get Setting name from route and set it in page_name variable */
		$this->setting_name = explode('/', $this->url->get('route'))[1];
	}
	/**
	* Setting index edit method
	* This method will be called on Setting edit view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Get setting data according to setting name and set it in data array to pass to view */
		$data['result'] = $this->settingModel->getSetting($this->setting_name);

		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'setting/action';
		/*Render Setting view*/

		$this->view->render('setting/'.$this->setting_name.'.tpl', $data);
	}
	
	public function indexAction()
	{
		if ($this->url->post('setting-name') == "generalsetting") {
			$this->updateGeneralSetting();
		} elseif ( $this->commons->validateToken($this->url->post('_token')) ) {
			$this->url->redirect('setting/'.$this->url->post('setting-name'));
			exit();
		} else {
			$this->update();
		}
		
	}

	protected function update()
	{
		$data['name'] = $this->url->post('setting-name');
		if ($data['name'] === 'analytics') {
			$data['data'] = json_encode($this->url->post('google-analytics'));	
		}
		elseif ($data['name'] === 'customcss') {
			$data['data'] = json_encode($this->url->post('custom-css'));
		} elseif ($data['name'] === 'paymentgateway') {
			$data['data'] = json_encode($this->url->post('setting'));
		}

		$data['status'] = $this->url->post('status');
		if ($this->settingModel->settingUpdate($data)) {
			$this->session->data['message'] = array('alert' => 'success', 'value' => ucfirst($data['name']).' updated successfully.');
		}
		else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => ucfirst($data['name']). ' does not updated.');
		}
		$this->url->redirect('setting/'. $data['name']);
	}

	public function updateGeneralSetting()
	{
		$data = $this->url->post('general');
		$data['name'] = $this->url->post('setting-name');
		$result = $this->settingModel->generalSettingUpdate($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Settings updated successfully.');
		$this->url->redirect('setting/'. $data['name']);
	}
}