<?php

/**
* Testimonial Controller
*/
class TestimonialController extends Controller
{
	/**
	* Private Testimonial model variable
	* This will be used for calling Testimonial model's function
	**/
	private $testimonialModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize Testimonial model*/
		$this->testimonialModel = new Testimonial();
	}
	/**
	* Testimonial index edit method
	* This method will be called on blog Testimonial view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all Testimonial data from DB using Testimonial model 
		**/
		$data['result'] = $this->testimonialModel->allTestimonials();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/*Render testimonial list view*/
		$this->view->render('themeoption/testimonial_list.tpl', $data);
	}
	/**
	* Testimonial index add method
	* This method will be called on Testimonial add
	**/
	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add Testimonial';
		/* Set empty data to array */
		$data['result'] =  NULL;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'themeoption/testimonial/action';
		/*Render Testimonial add view*/
		$this->view->render('themeoption/testimonial_form.tpl', $data);
	}
	/**
	* Testimonial index edit method
	* This method will be called on Testimonial edit view
	**/
	public function indexEdit()
	{	
		/**
		* Check if id exist in url if not exist then redirect to Testimonial list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('themeoption/testimonial');
		}
		/**
		* Check Testimonial exist or not 
		* If not than redirect to testimonial list view
		**/
		$testimonial = $this->testimonialModel->getTestimonial($id);
		if (!$testimonial) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'Testimonial does not exist in database!');
			$this->url->redirect('themeoption/testimonial');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/*Create array to pass to view*/
		$data['page_title'] = 'Edit Testimonial';
		$data['result'] = $testimonial;

		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'themeoption/testimonial/action';
		/*Render Testimonial edit view*/
		$this->view->render('themeoption/testimonial_form.tpl', $data);
	}/**
	* Info index action method
	* This method will be called on Info submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('request');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter valid '.implode(", ",$validate_field).'!');
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('themeoption/testimonial/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('themeoption/testimonial/add');
			}
		}

		if ($this->commons->validateToken($this->url->post('_token'))){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('themeoption/testimonial/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('themeoption/testimonial/add');
			}
		}

		if (!empty($this->url->post('id'))) {
			$this->update();
		}
		else {
			$this->create();
		}
	}
	/**
	* Blog index delete method
	* This method will be called on blog delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id')) ) {
			$this->url->redirect('themeoption/testimonial');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	protected function update()
	{
		$data['id'] = $this->url->post('id');
		$data['name'] = $this->url->post('name');
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['picture'] = $this->url->post('testimonial-picture');
		$data['testimonial'] = $this->url->post('testimonial');
		$data['status'] = $this->url->post('status');

		$this->testimonialModel->updateTestimonial($data);
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Testimonial updated successfully.');
		$this->url->redirect('themeoption/testimonial/edit&id='.$data['id']);
	}

	protected function create()
	{
		$data['name'] = $this->url->post('name');
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['picture'] = $this->url->post('testimonial-picture');
		$data['testimonial'] = $this->url->post('testimonial');
		$data['status'] = $this->url->post('status');

		if ($result = $this->testimonialModel->createTestimonial($data)) {
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Testimonial created successfully.');
			$this->url->redirect('themeoption/testimonial/edit&id='.$result);
		}
		else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Testimonial does not created (Server Error).');
			$this->url->redirect('themeoption/testimonial/add');
		}
	}

	protected function delete()
	{
		$result = $this->testimonialModel->deleteTestimonial($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Testimonial deleted successfully.');
		$this->url->redirect('themeoption/testimonial');
	}

	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($this->commons->validateText($this->url->post('name'))) {
			$error_flag = true;
			$error['name'] = 'Name';
		}

		if ($this->commons->validateText($this->url->post('testimonial'))) {
			$error_flag = true;
			$error['testimonial'] = 'Person Testimonial';
		}

		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}