<?php

/**
* User Controller
*/
class UserController extends Controller
{
	/**
	* Private User model variable
	* This will be used for calling User model's function
	**/
	private $userModel;
	function __construct()
	{
		parent::__construct();
		$this->commons = new CommonsController();
		/*Intilize User model*/
		$this->userModel = new User();
	}
	/**
	* User index method
	* This method will be called on User list view
	**/
	public function index()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all User data from DB using User model 
		**/
		$data['result'] = $this->userModel->allUsers();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/* Set page title */
		$data['page_title'] = 'Users';
		$data['link'] = 'user';
		$data['user_type'] = 2;
		/*Render User list view*/
		$this->view->render('user/user_list.tpl', $data);
	}
	/**
	* patient index method
	* This method will be called on User list view
	**/
	public function indexPatients()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/**
		* Get all User data from DB using User model 
		**/
		$data['result'] = $this->userModel->allPatients();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		/* Set page title */
		$data['page_title'] = 'Patients';
		$data['link'] = 'patient';
		$data['user_type'] = 1;
		/*Render User list view*/
		$this->view->render('user/user_list.tpl', $data);
	}
	/**
	* User index add method
	* This method will be called on User add
	**/
	public function indexAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add User';
		/* Set empty data to array */
		$data['result'] =  NULL;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['access'] = 2;
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'user/action';
		$data['link'] = 'user';
		$data['user_type'] = 2;
		/*Render User add view*/
		$this->view->render('user/user_form.tpl', $data);
	}

	/**
	* User index add method
	* This method will be called on User add
	**/
	public function indexPatientAdd()
	{
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		/* Set page title */
		$data['page_title'] = 'Add Paitent';
		/* Set empty data to array */
		$data['result'] =  NULL;
		$data['access'] = 2;
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		
		if ($data['user']['role'] == "Doctor") {
			$data['access'] = 1;
		} else {
			$data['access'] = 2;
		}
		
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'user/action';
		$data['link'] = 'patient';
		$data['user_type'] = 1;
		/*Render User add view*/
		$this->view->render('user/user_form.tpl', $data);
	}
	/**
	* User index edit method
	* This method will be called on User edit view
	**/
	public function indexEdit()
	{
		/**
		* Check if id exist in url if not exist then redirect to User list view 
		**/
		$id = (int)$this->url->get('id');
		if (empty($id) || !is_int($id) || $id == 1) {
			$this->url->redirect('user');
		}
		/**
		* Call getUser method from Blog model to get data from DB for single User
		* If User does not exist then redirect it to User list view
		**/
		$user = $this->userModel->getUser($id);
		if (!$user) {
			$this->session->data['message'] = array('alert' => 'warning', 'value' => 'User does not exist in database!');
			$this->url->redirect('user');
		}
		/*Get User name and role*/
		$data['user'] = $this->commons->getUser();
		if ($data['user']['role'] == "Doctor") {
			$data['access'] = 1;
		} else {
			$data['access'] = 2;
		}
		/*Create data array to pass to view*/
		$data['page_title'] = 'Edit User';
		$data['result'] = $user;
		if ($user['user_role'] == 1) {
			$data['user_type'] = 1;
			$data['link'] = "patient";
			$data['page_title'] = "Edit Patient";
		} else {
			$data['user_type'] = 2;
			$data['link'] = "user";
			$data['page_title'] = "Edit User";
		}

		/*Get user's appointments from DB*/
		$data['appointments'] = $this->userModel->userAppointmentList($user['email'], $user['user_id']);
		/*Get user's inovices from DB*/
		$data['invoices'] = $this->userModel->userInvoicetList( $user['email'] );
		/*Get all doctors*/
		$this->appointmentModel = new Appointment();
		$data['doctors'] = $this->appointmentModel->getDoctors();
		/* Set confirmation message if page submitted before */
		if (isset($this->session->data['message'])) {
			$data['message'] = $this->session->data['message'];
			unset($this->session->data['message']);
		}
		$data['reports'] = $this->userModel->getUserReports($user['email']);
		
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['action'] = URL_ADMIN.DIR_ROUTE.'user/action';
		$data['appointment_action'] = URL_ADMIN.DIR_ROUTE.'appointment/dashboardappointment';
		/*Render User edit view*/
		$this->view->render('user/user_form.tpl', $data);
	}
	/**
	* Info index action method
	* This method will be called on Info submit/save view
	**/
	public function indexAction()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['submit'])) {
			$this->url->redirect('user');
			exit();
		}
		/**
		* Validate form data
		* If some data is missing or data does not match pattern
		* Return to info view 
		**/
		if ($validate_field = $this->validateField()) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Please enter/select valid '.implode(", ",$validate_field).'!');
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('user/edit&id='.$this->url->post('id'));
			}
			else {
				$this->url->redirect('user/add');
			}
		}
		
		if ($this->commons->validateToken($this->url->post('_token'))){
			if (!empty($this->url->post('id'))) {
				$this->url->redirect('user/edit&id='.$this->url->post('id'));
			} else {
				$this->url->redirect('user/add');
			}
		}

		if (!empty($this->url->post('id'))) {
			$this->update();
		} else {
			$this->create();
		}
	}
	/**
	* User index delete method
	* This method will be called on blog delete action
	**/
	public function indexDelete()
	{
		/**
		* Check if from is submitted or not 
		**/
		if (!isset($_POST['delete']) || empty($this->url->post('id'))) {
			$this->url->redirect('user');
			exit();
		}
		/**
		* Call delete method
		**/
		$this->delete();
	}

	protected function update()
	{
		if (!empty($this->url->post('username'))) {
			$check_user = $this->userModel->checkUserName($this->url->post('username'), $this->url->post('email'));
			if ($check_user >= 1) {
				$this->session->data['message'] = array('alert' => 'danger', 'value' => 'User Name  \'' .$this->url->post('username').' \' already exist in database.');
				$this->url->redirect('user/edit&id='.$this->url->post('id'));
				
			}
		}
		$data['id'] = $this->url->post('id');
		$data['username'] = (!empty($this->url->post('username'))) ? $this->url->post('username') : NULL;
		$data['firstname'] = $this->url->post('firstname');
		$data['lastname'] = $this->url->post('lastname');
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['dob'] = $this->url->post('dob');
		$data['location'] = $this->url->post('location');
		$data['country'] = $this->url->post('country');
		$data['bloodgroup'] = $this->url->post('bloodgroup');
		$data['about'] = json_encode($this->url->post('medical'));
		$data['status'] = $this->url->post('status');
		$data['gender'] = $this->url->post('gender');
		$data['role'] = $this->url->post('role');
		
		$result = $this->userModel->updateUser($data);
		if ($result && $this->url->post('sendmail')) {
			$message = file_get_contents(DIR_APP.'views/mail_template/update-user.tpl');
			$message = str_replace('{name}', $data['firstname'].' '.$data['lastname'], $message);
			$message = str_replace('{username}', $data['username'], $message);
			$message = str_replace('{site_name}', NAME, $message);
			$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
			$mailer = new Mailer();
			$mailer->mail->setFrom(SITEEMAIL, NAME);
			$mailer->mail->addAddress($data['email'], $data['firstname']);
			$mailer->mail->isHTML(true);
			$mailer->mail->Subject = 'Account updated by '.NAME;
			$mailer->mail->Body = $message;

			$mailer->mail->AltBody = 'Hello '.$data['firstname'].'. Your account details has been updated. For more info please log in to your account.';
			$mailer->sendMail();
		}
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Account updated successfully.');
		$this->url->redirect('user/edit&id='.$data['id']);
	}

	protected function create()
	{
		/**
		* Check if @user_name already exist or not in database
		**/
		if (!empty($this->url->post('username'))) {
			$check_user = $this->userModel->checkUserName($this->url->post('username'), $this->url->post('email'));
			if ($check_user >= 1) {
				$this->session->data['message'] = array('alert' => 'danger', 'value' => 'User Name  \'' .$this->url->post('username').' \' already exist in database.');
				$this->url->redirect('user/add');
			}
		}
		/**
		* Check if @email already exist or not in database
		**/
		if ($this->userModel->checkUserEmail($this->url->post('email')) >= 1) {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Email  \'' . $this->url->post('email') . '\'  already exist in database.');
			$this->url->redirect('user/add');
		}
		/**
		* Set all data to one array to pass it to model
		**/		
		$data['username'] = !empty($this->url->post('username')) ? $this->url->post('username') : NULL;
		$data['role'] = $this->url->post('role');
		$data['firstname'] = $this->url->post('firstname');
		$data['lastname'] = $this->url->post('lastname');
		$data['password'] = password_hash($this->url->post('password'), PASSWORD_DEFAULT);
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['dob'] = $this->url->post('dob');
		$data['location'] = $this->url->post('location');
		$data['country'] = $this->url->post('country');
		$data['bloodgroup'] = $this->url->post('bloodgroup');
		$data['about'] = json_encode($this->url->post('medical'));
		$data['gender'] = $this->url->post('gender');
		$data['hash'] = md5(uniqid(mt_rand(), true));
		/**
		* Call user model to create user
		* If user created than send email and set success message 
		* If not than set error 
		**/
		if ($result = $this->userModel->createUser($data)) {
			if ($this->url->post('sendmail')) {
				$message = file_get_contents(DIR_APP.'views/mail_template/create-user.tpl');
				$message = str_replace('{name}', $data['firstname'].' '.$data['lastname'], $message);
				$message = str_replace('{email}', $data['email'], $message);
				$message = str_replace('{mobile}', $data['mobile'], $message);
				$message = str_replace('{username}', $data['username'], $message);
				$message = str_replace('{password}', $this->url->post('password'), $message);
				$message = str_replace('{code}', $data['hash'], $message);
				$message = str_replace('{site_name}', NAME, $message);
				$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
				$mailer = new Mailer();
				$mailer->mail->setFrom(SITEEMAIL, NAME);
				$mailer->mail->addAddress($data['email'], $data['firstname']);
				$mailer->mail->isHTML(true);
				$mailer->mail->Subject = 'Account created with '.NAME.', please verify your account';
				$mailer->mail->Body = $message;

				$mailer->mail->AltBody = 'Hello '.$data['firstname'].'.
				Welcome to '.URL. PHP_EOL.' Your account has been created.';
				$mailer->sendMail();
			}
			$this->session->data['message'] = array('alert' => 'success', 'value' => 'Account created successfully.');
			$this->url->redirect('user/edit&id='.$result);
		} else {
			$this->session->data['message'] = array('alert' => 'danger', 'value' => 'Account does not created (Server Error).');
			$this->url->redirect('user/add');
		}
	}
	/**
	* Delete Function or method
	* This function is going to delete user from database
	**/
	protected function delete()
	{
		$result = $this->userModel->deleteUser($this->url->post('id'));
		$this->session->data['message'] = array('alert' => 'success', 'value' => 'Account deleted successfully.');
		$this->url->redirect('user');
	}
	/**
	* Validate user field from server side
	**/
	protected function validateField()
	{
		$error = [];
		$error_flag = false;
		if ($this->commons->validateText($this->url->post('firstname'))) {
			$error_flag = true;
			$error['firstname'] = 'First Name';
		}
		if ($this->commons->validateText($this->url->post('lastname'))) {
			$error_flag = true;
			$error['lastname'] = 'Last Name';
		}
		if ($this->commons->validateEmail($this->url->post('email'))) {
			$error_flag = true;
			$error['email'] = 'Email Address';
		}
		if ($this->commons->validatePhoneNumber($this->url->post('mobile'))) {
			$error_flag = true;
			$error['mobile'] = 'Mobile Number';
		}
		if ($error_flag) {
			return $error;
		} else {
			return false;
		}
	}
}