<?php

/**
* Appointment Model
*/
class Appointment extends Model
{
	public function allAppointments()
	{
		$query = $this->model->query("SELECT a.id, a.name, a.email, a.mobile, a.date, a.time, a.status, a.invoice_id, a.appointment_id, a.invoice_id, d.id AS doctor_id, d.name As doctor, d.picture AS picture, d.email AS doctor_email, dep.name AS department, user.user_id AS user_id FROM `" . DB_PREFIX . "appointment` AS a LEFT JOIN `" . DB_PREFIX . "doctor` AS d ON d.id = a.doctor_id LEFT JOIN `" . DB_PREFIX . "department` AS dep ON dep.id = a.department_id LEFT JOIN `" . DB_PREFIX . "users` AS user ON user.email = a.email ORDER BY date DESC");
		$result = [];
		$status = 'new';
		if ($query->num_rows > 0) {
			foreach ($query->rows as $key => $value) {
				if ($value['status'] == 1) {
					$status = 'canceled';
				} elseif ($value['status'] == 2) {
					$status = 'in-process';
				} elseif ($value['status'] == 3) {
					$status = 'confirmed';
				} elseif ($value['status'] == 4) {
					$status = 'completed';
				} else {
					$status = 'new';
				}
				$result[] = array(
					'id'    => $value['id'],
					'name'   => $value['name'],
					'email'     => $value['email'],
					'mobile'     => $value['mobile'],
					'date'     => date_format(date_create($value['date']),"d M Y"),
					'time'     => $value['time'],
					'status'     => $status,
					'invoice_id'     => $value['invoice_id'],
					'doctor_id'     => $value['doctor_id'],
					'doctor'     => $value['doctor'],
					'doctor_email'     => $value['doctor_email'],
					'picture'     => $value['picture'],
					'department'     => $value['department'],
					'invoice'     => $value['invoice_id'],
					'user_id'     => $value['user_id'],
					'appointment_id'     => $value['appointment_id']
					);
			}
		}
		return $result;
	}

	public function getAppointment($id)
	{
		$query = $this->model->query("SELECT a.*, d.name AS department, p.id AS prescription_id, p.prescription AS prescription, u.user_id AS userid, u.bloodgroup, u.gender, u.dob FROM `" . DB_PREFIX . "appointment` AS a LEFT JOIN `" . DB_PREFIX . "department` AS d ON d.id = a.department_id LEFT JOIN `" . DB_PREFIX . "prescription` AS p ON p.appointment_id = a.id LEFT JOIN `" . DB_PREFIX . "users` AS u ON u.email = a.email WHERE a.id = ? LIMIT 1", array((int)$id));
		if ($query->num_rows > 0) {
			return $query->row;
		} else {
			return false;
		}
	}

	public function grtPrescription($id)
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "prescription` WHERE appointment_id = ? LIMIT 1", array((int)$id));
		if ($query->num_rows > 0) {
			return $query->row;
		} else {
			return false;
		}
	}

	public function updateAppointment($data)
	{
		$query = $this->model->query("UPDATE `" . DB_PREFIX . "appointment` SET `name` = ?, `email` = ?, `mobile` = ?,  `date` = ?, `time` = ?, `department_id` = ?, `status` = ?, `doctor_id` = ?, `note` = ?, `doctor_note` = ? WHERE `id` = ? " , array($this->model->escape($data['name']), $this->model->escape($data['email']), $this->model->escape($data['mobile']), $this->model->escape($data['date']), $this->model->escape($data['time']), (int)$data['department'], (int)$data['status'], (int)$data['doctor'], $data['note'], $data['doctornote'], (int)$data['id']));
		if ($query->num_rows > 0) {
			return true;
		} else {
			return false;
		}
	}

	public function updatePrescription($data)
	{
		$query = $this->model->query("UPDATE `" . DB_PREFIX . "prescription` SET `email` = ?, `prescription` = ?, `doctor_id` = ? WHERE `id` = ? " , array($this->model->escape($data['email']), $data['prescription'], (int)$data['doctor'], (int)$data['prescription_id']));
		if ($query->num_rows > 0) {
			return true;
		} else {
			return false;
		}
	}

	public function createPrescription($data)
	{
		$query = $this->model->query("INSERT INTO `" . DB_PREFIX . "prescription` (`email`, `prescription`, `doctor_id`, `appointment_id`) VALUES (?, ?, ?, ?) " , array($this->model->escape($data['email']), $data['prescription'], (int)$data['doctor'], (int)$data['id']));
		if ($query->num_rows > 0) {
			return true;
		} else {
			return false;
		}
	}

	public function createAppointment($data)
	{
		$query = $this->model->query("INSERT INTO `" . DB_PREFIX . "appointment` (`name`, `email`, `mobile`, `date`, `time`, `department_id`, `status`, `doctor_id`, `appointment_id` ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?) " , array($this->model->escape($data['name']), $this->model->escape($data['email']), $this->model->escape($data['mobile']), $this->model->escape($data['date']), $this->model->escape($data['time']), (int)$data['department'], (int)$data['status'], (int)$data['doctor'], $data['appointment_id']));
		if ($query->num_rows > 0) {
			return $this->model->last_id();
		} else {
			return false;
		}
	}

	public function getDoctors()
	{
		$query = $this->model->query("SELECT doc.id, doc.name, doc.department_id, doc.weekly, doc.national, dep.name AS department FROM `" . DB_PREFIX . "doctor` AS doc LEFT JOIN `" . DB_PREFIX . "department` AS dep ON dep.id = doc.department_id WHERE doc.appointment = ? ORDER BY doc.department_id ASC", array(1));
		return $query->rows;
	}

	public function getDoctorData($id)
	{
		$query = $this->model->query("SELECT `name`, `email` FROM `" . DB_PREFIX . "doctor` WHERE id = ? LIMIT 1", array(1));
		return $query->row;
	}

	public function getPharmacy()
	{
		$query = $this->model->query("SELECT `id` AS `value`, `name` AS `label`, `generic` AS `desc` FROM `" . DB_PREFIX . "pharmacy`");
		return $query->rows;
	}
	
	public function getDoctorTime($doctor)
	{
		$query = $this->model->query("SELECT `time` FROM `" . DB_PREFIX . "doctor` WHERE `id` = ? LIMIT 1", array($this->model->escape($doctor)));
		if ($query->num_rows > 0) {
			return  $query->row['time'];
		} else {
			return false;
		}
	}
	
	public function bookedSlot($date, $doctor)
	{
		$date = date("Y-m-d", strtotime($date));
		$query = $this->model->query("SELECT `time` FROM `" . DB_PREFIX . "appointment` WHERE `date`= ? AND `doctor_id` = ? AND `status` != ? ", array($this->model->escape($date), $this->model->escape($doctor), 1));
		$result = [];
		if ($query->num_rows > 0) {
			foreach ($query->rows as $key => $value) {
				$result[] = $value['time'];
			}
		}
		return $result;
	}

	public function deleteAppointment($id)
	{
		$query = $this->model->query("DELETE FROM `" . DB_PREFIX . "appointment` WHERE `id` = ?" ,
			array((int)$id));
		if ($query->num_rows > 0) {
			return true;
		} else {
			return false;
		}
	}

	public function dashboardUpdateAppointment($data)
	{
		$query = $this->model->query("UPDATE `" . DB_PREFIX . "appointment` SET `name` = ?, `email` = ?, `mobile` = ?,  `date` = ?, `time` = ?, `department_id` = ?, `status` = ?, `doctor_id` = ? WHERE `id` = ?", array($this->model->escape($data['name']), $this->model->escape($data['email']), $this->model->escape($data['mobile']), $this->model->escape($data['date']), $this->model->escape($data['time']), (int)$data['department'], (int)$data['status'], (int)$data['doctor'], (int)$data['id']));
		if ($query->num_rows > 0) {
			return true;
		} else {
			return false;
		}
	}

	public function getReports($id)
	{
		$query = $this->model->query("SELECT `id`, `report` FROM `" . DB_PREFIX . "reports` WHERE `appointment_id` = ?", array((int)$id));
		if ($query->num_rows > 0) {
			return  $query->rows;
		} else {
			return false;
		}
	}
}