<?php

/**
* Dashboard Model
*/

class Dashboard extends Model
{
	public function allAppointments()
	{
		$query = $this->model->query("SELECT a.id, a.name, a.email, a.mobile, a.date, a.time, a.department_id, a.status , a.doctor_id, d.name As doctor FROM `" . DB_PREFIX . "appointment` AS a LEFT JOIN `" . DB_PREFIX . "doctor` AS d ON d.id = a.doctor_id ORDER BY date DESC");
		return $query->rows;
	}

	public function doctorStatistics()
	{
		$query = $this->model->query("SELECT d.name, COUNT(a.doctor_id) AS count FROM `" . DB_PREFIX . "appointment` AS a LEFT JOIN `" . DB_PREFIX . "doctor` AS d ON d.id = a.doctor_id GROUP BY d.id");
		return $query->rows;
	}

	public function clinicTotalCount()
	{
		$query = $this->model->query("(SELECT count(*) AS `total` FROM `" . DB_PREFIX . "users`) UNION ALL (SELECT count(*) AS `total` FROM `" . DB_PREFIX . "appointment`) UNION ALL (SELECT count(*) AS `total` FROM `" . DB_PREFIX . "invoice`) UNION ALL (SELECT count(*) AS `total` FROM `" . DB_PREFIX . "request`) UNION ALL (SELECT count(*) AS `total` FROM `" . DB_PREFIX . "review`) UNION ALL (SELECT count(*) AS `total` FROM `" . DB_PREFIX . "comment`)");
		return $query->rows;
	}

	public function appointmentCount()
	{
		$query = $this->model->query("SELECT count(*) AS `total` FROM `" . DB_PREFIX . "appointment`");
		return $query->row['total'];
	}

	public function userCount()
	{
		$query = $this->model->query("SELECT count(*) AS `total` FROM `" . DB_PREFIX . "users`");
		return $query->row['total'];
	}

	public function invoiceCount()
	{
		$query = $this->model->query("SELECT count(*) AS `total` FROM `" . DB_PREFIX . "invoice`");
		return $query->row['total'];
	}

	public function requestCount()
	{
		$query = $this->model->query("SELECT count(*) AS `total` FROM `" . DB_PREFIX . "request`");
		return $query->row['total'];
	}

	public function subscriberCount()
	{
		$query =$this->model->query("SELECT count(*) AS `total` FROM `" . DB_PREFIX . "subscribe`");
		return $query->row['total'];
	}

	public function getRecentlyAdded()
	{
		$query = $this->model->query("(SELECT 'appointment' AS `table_name`, `id`, `name`, `date_of_joining` FROM `" . DB_PREFIX . "appointment` ) UNION (SELECT 'request' AS `table_name`, `id`, `name`, `date_of_joining` FROM `" . DB_PREFIX . "request`) UNION (SELECT 'invoice' AS `table_name`, `id`, `name`, `date_of_joining` FROM `" . DB_PREFIX . "invoice`) UNION (SELECT 'user' AS `table_name`, `user_id` AS `id`, concat(`firstname`,' ',`lastname`) AS `name`, `date_of_joining` FROM `" . DB_PREFIX . "users`) ORDER BY `date_of_joining` DESC LIMIT 7");
		return $query->rows;
	}

	public function clinicStats()
	{
		$query = $this->model->query("SELECT YEAR(date) AS YEAR, SUM(MONTH(date) = 1) AS JAN , SUM(MONTH(date) = 2) AS FEB , SUM(MONTH(date) = 3) AS MAR , SUM(MONTH(date) = 4) AS APR, SUM(MONTH(date) = 5) AS MAY , SUM(MONTH(date) = 6) AS JUNE , SUM(MONTH(date) = 7) AS JULY , SUM(MONTH(date) = 8) AS AUG, SUM(MONTH(date) = 9) AS SEP , SUM(MONTH(date) = 10) AS OCT , SUM(MONTH(date) = 11) AS NOV , SUM(MONTH(date) = 12) AS `DEC`, COUNT(*) FROM zz_appointment WHERE date >= NOW() - INTERVAL 6 MONTH");
		return $query->row;
	}

	public function appointmentStats()
	{
		$query = $this->model->query("SELECT DATE_FORMAT(`date`,'%b') AS `month`, COUNT(*) AS `count` FROM `" . DB_PREFIX . "appointment` WHERE MONTH(`date`) <= DATE_SUB(CURDATE(), INTERVAL 6 MONTH) GROUP BY MONTH(`date`)");
		return $query->rows;
	}

	public function invoiceStats()
	{
		$query = $this->model->query("SELECT DATE_FORMAT(`date_of_joining`,'%b') AS `month`, COUNT(*) AS `count` FROM `" . DB_PREFIX . "invoice` WHERE MONTH(`date_of_joining`) <= MONTH(NOW()) AND MONTH(`date_of_joining`) > MONTH(NOW()) - 6 GROUP BY MONTH(`date_of_joining`)");
		return $query->rows;
	}

	public function userStats()
	{
		$query = $this->model->query("SELECT DATE_FORMAT(`date_of_joining`,'%b') AS `month`, COUNT(*) AS `count` FROM `" . DB_PREFIX . "users` WHERE MONTH(`date_of_joining`) <= MONTH(NOW()) AND MONTH(`date_of_joining`) > MONTH(NOW()) - 6 GROUP BY MONTH(`date_of_joining`)");
		return $query->rows;
	}

	public function getEarnings()
	{
		$query = $this->model->query("SELECT DATE_FORMAT(`date_of_joining`,'%b') AS `month`, SUM(`amount`) AS `count` FROM `" . DB_PREFIX . "invoice` WHERE MONTH(`date_of_joining`) <= MONTH(NOW()) AND MONTH(`date_of_joining`) > MONTH(NOW()) - 6 GROUP BY MONTH(`date_of_joining`)");
		return $query->rows;
	}
}