<?php
/**
* User Model
*/
class User extends Model
{
	public function allUsers()
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "users` WHERE `user_role` != ? ORDER BY `date_of_joining` DESC", array(1));
		$result = [];
		$role = '';
		if ($query->num_rows > 0) {
			foreach ($query->rows as $key => $value) {
				if ($value['user_role'] == '10') { $role = "Admin"; }
				elseif ($value['user_role'] == '4') { $role = "Dean"; }
				elseif ($value['user_role'] == '3') { $role = "Doctor"; }
				elseif ($value['user_role'] == '2') { $role = "Handler"; }
				else { $role = "Patient"; }
				$result[] = array(
					'id'    => $value['user_id'],
					'username'    => $value['user_name'],
					'role'    => $role,
					'firstname'   => $value['firstname'],
					'lastname'   => $value['lastname'],
					'email'     => $value['email'],
					'mobile'     => $value['mobile'],
					'date'     => date_format(date_create($value['date_of_joining']),"d M Y"),
					'status'     => $value['status']
				);
			}
		}
		return $result;
	}

	public function allPatients()
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "users` WHERE `user_role` = ? ORDER BY `date_of_joining` DESC", array(1));
		$result = [];
		$role = '';
		if ($query->num_rows > 0) {
			foreach ($query->rows as $key => $value) {
				if ($value['user_role'] == '10') { $role = "Admin"; }
				elseif ($value['user_role'] == '4') { $role = "Dean"; }
				elseif ($value['user_role'] == '3') { $role = "Doctor"; }
				elseif ($value['user_role'] == '2') { $role = "Handler"; }
				else { $role = "Paitent"; }
				$result[] = array(
					'id'    => $value['user_id'],
					'username'    => $value['user_name'],
					'role'    => $role,
					'firstname'   => $value['firstname'],
					'lastname'   => $value['lastname'],
					'email'     => $value['email'],
					'mobile'     => $value['mobile'],
					'date'     => date_format(date_create($value['date_of_joining']),"d M Y"),
					'status'     => $value['status']
				);
			}
		}
		return $result;
	}


	public function getUser($id)
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "users` WHERE `user_id` = ? LIMIT 1", array($this->model->escape($id)));
		if ($query->num_rows > 0) {
			return $query->row;
		} else {
			return false;
		}
	}

	public function userAppointmentList($email, $user_id)
	{
		$query = $this->model->query("SELECT a.*, d.id As dctr_id, d.name As doctor, d.picture, d.email As doctor_email, dep.name AS department FROM `" . DB_PREFIX . "appointment` AS a LEFT JOIN `" . DB_PREFIX . "doctor` AS d ON d.id = a.doctor_id LEFT JOIN `" . DB_PREFIX . "department` AS dep ON a.department_id = dep.id WHERE a.email = ? OR a.user_id = ? ORDER BY a.date DESC", array($this->model->escape($email), $this->model->escape($user_id)));
		$result = [];
		if ($query->num_rows > 0) {
			foreach ($query->rows as $key => $value) {
				$status = 'new';
				if ($value['status'] === 1) { $status = 'canceled'; } 
				elseif ($value['status'] === 2) { $status = 'in-process'; } 
				elseif ($value['status'] === 3) { $status = 'confirmed'; } 
				elseif ($value['status'] === 4) { $status = 'completed'; } 
				else { $value['status'] = 'new'; }
				$result[] = array(
					'id' => $value['id'],
					'appointment_id' => $value['appointment_id'],
					'date' => date_format(date_create($value['date']),"d M Y"),
					'time' => $value['time'],
					'doctor_id' => $value['dctr_id'],
					'doctor' => $value['doctor'],
					'doctor_email' => $value['doctor_email'],
					'picture' => $value['picture'],
					'department' => $value['department'],
					'invoice_id' => $value['invoice_id'],
					'status' => $status
				);
			}
		}
		return $result;
	}

	public function userInvoicetList($email)
	{
		$query = $this->model->query("SELECT i.id, i.name, i.email, i.mobile, i.amount, i.due, d.name AS `doctor`, i.date_of_joining AS `date`, c.abbr FROM `" . DB_PREFIX . "invoice` AS i LEFT JOIN `" . DB_PREFIX . "doctor` AS d ON d.id = i.doctor_id LEFT JOIN `" . DB_PREFIX . "currency` AS c ON c.id = i.currency WHERE i.email = ? ORDER BY i.date_of_joining DESC", array($this->model->escape($email)));
		return $query->rows;
	}

	public function checkUserName($username, $email)
	{
		$query = $this->model->query("SELECT count(*) AS total FROM `" . DB_PREFIX . "users` WHERE `user_name` = ? AND `email` != ?", array($this->model->escape($username), $this->model->escape($email)));
		if ( $query->num_rows > 0 ) {
			return $query->row['total'];
		} else {
			return false;
		}
	}

	public function checkUserEmail($email)
	{
		$query = $this->model->query("SELECT count(*) AS total FROM `" . DB_PREFIX . "users` WHERE `email` = ? ", array($this->model->escape($email)));
		if ($query->num_rows > 0) {
			return $query->row['total'];
		} else{
			return false;
		}
	}

	public function updateUser($data)
	{
		if ($data['username']) {
			$query = $this->model->query("UPDATE `" . DB_PREFIX . "users` SET `user_role` = ?, `user_name` = ?, `firstname` = ?, `lastname` = ?, `mobile` = ?, `location` = ?, `country` = ?, `bloodgroup` = ?, `gender` = ?, `about` = ?, `dob` = ?, `status` = ? WHERE `user_id` = ? AND `email` = ? " , array($this->model->escape($data['role']), $this->model->escape($data['username']), $this->model->escape($data['firstname']), $this->model->escape($data['lastname']), $this->model->escape($data['mobile']), $this->model->escape($data['location']), $this->model->escape($data['country']), $this->model->escape($data['bloodgroup']), (int)$data['gender'], $data['about'], $this->model->escape($data['dob']), (int)$data['status'], (int)$data['id'], $this->model->escape($data['email'])));
		} else {
			$query = $this->model->query("UPDATE `" . DB_PREFIX . "users` SET `user_role` = ?, `firstname` = ?, `lastname` = ?, `mobile` = ?, `location` = ?, `country` = ?, `bloodgroup` = ?, `gender` = ?, `about` = ?, `dob` = ?, `status` = ? WHERE `user_id` = ? AND `email` = ? " , array($this->model->escape($data['role']), $this->model->escape($data['firstname']), $this->model->escape($data['lastname']), $this->model->escape($data['mobile']), $this->model->escape($data['location']), $this->model->escape($data['country']), $this->model->escape($data['bloodgroup']), (int)$data['gender'], $data['about'], $this->model->escape($data['dob']), (int)$data['status'], (int)$data['id'], $this->model->escape($data['email'])));
		}
		
		if ($query->num_rows > 0) { 
			return false;
		} else { 
			return true;
		}
	}

	public function createUser($data)
	{
		if ($data['username']) {
			$query = $this->model->query("INSERT INTO `" . DB_PREFIX . "users` (`user_role`, `user_name`, `firstname`, `lastname`, `email`, `mobile`, `location`, `country`, `bloodgroup`, `gender`, `about`, `dob`, `password`, `temp_hash`) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", array($this->model->escape($data['role']), $this->model->escape($data['username']), $this->model->escape($data['firstname']), $this->model->escape($data['lastname']), $this->model->escape($data['email']), $this->model->escape($data['mobile']), $this->model->escape($data['location']), $this->model->escape($data['country']), $this->model->escape($data['bloodgroup']), (int)$data['gender'], $data['about'], $this->model->escape($data['dob']), $data['password'], $data['hash']));
		} else {
			$query = $this->model->query("INSERT INTO `" . DB_PREFIX . "users` (`user_role`, `firstname`, `lastname`, `email`, `mobile`, `location`, `country`, `bloodgroup`, `gender`, `about`, `dob`, `password`, `temp_hash`) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", array($this->model->escape($data['role']), $this->model->escape($data['firstname']), $this->model->escape($data['lastname']), $this->model->escape($data['email']), $this->model->escape($data['mobile']), $this->model->escape($data['location']), $this->model->escape($data['country']), $this->model->escape($data['bloodgroup']), (int)$data['gender'], $data['about'], $this->model->escape($data['dob']), $data['password'], $data['hash']));
		}
		
		if ($this->model->error()) {
			return $this->model->error();
		} else {
			return $this->model->last_id();
		}
	}

	public function deleteUser($id)
	{
		$query = $this->model->query("DELETE FROM `" . DB_PREFIX . "users` WHERE `user_id` = ?", array((int)$id));
		if ($query->num_rows > 0) { 
			return true;
		} else {
			return false;
		}
	}

	public function getUserReports($email)
	{
		$query = $this->model->query("SELECT `report`, `appointment_id` FROM `" . DB_PREFIX . "reports` WHERE `email` = ?", array($this->model->escape($email)));
		if ($query->num_rows > 0) {
			return  $query->rows;
		} else {
			return false;
		}
	}
}