<?php
/**
* Appointment Controller
*/
class AppointmentController extends Controller
{
	/**
	* @user_id
	* Set User Id Null by default
	**/
	protected $user_id= NULL;
	function __construct() {
		/* Call parent constructor */
		parent::__construct();
		if (Common::isLoggedIn()) {
			$this->user_id = $this->session->data['user_id'];
		}
	}
	/**
	* Main Index method or function
	* This will be called on appointment request
	**/
	public function index() {
		$id = $this->url->post('form_id');
		$date = $this->url->post('date');
		$doctor = $this->url->post('doctor');
		/** 
		* Check if request is POST or not 
		* Validaate input field
        **/
		if (!$_SERVER['REQUEST_METHOD'] == 'POST' || !$this->validate($id, $date, $doctor)) {
			echo "No_Slot";
			exit();
		}
		$token = $this->url->post('token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false ) {
			echo 'Warning: Invalid token. Please try again.';
			exit();
		}
		/** 
		* Get doctor timing from db
        **/
		$this->createAppointmentSlot($date, $doctor);
	}

	public function appointmentSubmit() {
		$data = array(
			'form_id' => $this->url->post('form_id'),
			'name' => $this->url->post('name'),
			'email' => $this->url->post('email'),
			'mobile' => $this->url->post('mobile'),
			'department' => $this->url->post('department'),
			'date' => $this->url->post('date'),
			'doctor' => $this->url->post('doctor'),
			'time' => $this->url->post('time'),
			'user_id' => $this->user_id
			);
		/** 
		* Check if request is POST or not 
		* Validaate input field
        **/
		if (!$this->validateSubmit($data)) {
			echo "No_Slot";
			exit();
		}
		$token = $this->url->post('token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false ) {
			echo 'No_Slot';
			exit();
		}
		
		$this->appointmentModel = new Appointment();
		if ($checkAppointment = $this->appointmentModel->checkAppointment($data)) {
			$this->createAppointmentSlot($data['date'], $data['doctor']);
			exit();
		}
		else {
			$data['appointment_id'] = date('Ymd').rand(10,1000).date('his');
			$this->appointmentModel->createAppointment($data);
			$doctor = $this->appointmentModel->getDoctorData($data['doctor']);
			$message = file_get_contents(DIR_APP.'views/mail_template/create-appointment.tpl');
			$message = str_replace('{name}', $data['name'], $message);
			$message = str_replace('{email}', $data['email'], $message);
			$message = str_replace('{mobile}', $data['mobile'], $message);
			$message = str_replace('{doctor}', $doctor['name'], $message);
			$message = str_replace('{date}', $data['date'], $message);
			$message = str_replace('{time}', $data['time'], $message);
			$message = str_replace('{appointment_id}', $data['appointment_id'], $message);
			$message = str_replace('{site_name}', NAME, $message);
			$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
			$mailer = new Mailer();
			$mailer->mail->setFrom(SITEEMAIL, NAME);
			$mailer->mail->addAddress($data['email'], $data['name']);
			$mailer->mail->addBCC($doctor['email'], $doctor['name']);
			$mailer->mail->isHTML(true);
			$mailer->mail->Subject = 'Appointment Created at '.NAME;
			$mailer->mail->Body = $message;
				$mailer->mail->AltBody = 'Hello '.$data['name'].'.
					Your Appointment has been booked on '.$data['date'].' at '.$data['time'].'.
					Your Appointment ID : '.$data['appointment_id'].'';
			$mailer->sendMail();
			echo "1";
			exit();
		}
	}
	/**
	* Create appointment slot function
	* Get doctor appointment info and booked slot for specific date from DB
	* Return all appointment slot array
	**/
	protected function createAppointmentSlot($date, $doctor) {
		$this->appointmentModel = new Appointment();
		if (!$time = json_decode($this->appointmentModel->getDoctorTime($doctor), true)) {
			echo "No_Slot";
			exit();
		}
		$time_slot = $this->makeSlot($time);
		$booked_slot = $this->appointmentModel->bookedSlot($date, $doctor);
		$slot = [];
		$flag = 0;
		foreach ($time_slot as $key => $time) {
			foreach ($booked_slot as $booked) {
				if ($time === $booked) {
					$flag = 1;
				}
			}
			$slot[] = array(
				'time' => $time,
				'status' => $flag
				);
			$flag = 0;
		}
		echo json_encode($slot);
	}
	/**
	* Make Time slot accroding to start time, end time and time slot
	**/
	protected function makeSlot($time)
	{
		$time_slot = [];
		$st1 = strtotime($time['st1']);
		$et1 = strtotime($time['et1']);
		$st2 = strtotime($time['st2']);
		$et2 = strtotime($time['et2']);
		while ($st1 < $et1) {
			$time_slot[] = date ("H:i", $st1);
			$st1 += $time['slot']*60;
		}
		while ($st2 < $et2) {
			$time_slot[] = date ("H:i", $st2);
			$st2 += $time['slot']*60;
		}
		return $time_slot;
	}
	/**
	* Validate form input field on server side
	**/
	protected function validate($form_id, $date, $doctor) {
		if (filter_var($form_id, FILTER_VALIDATE_INT) === false) {
			/** 
			* Check form id, Is it int or string 
			* Return false
			**/
			return false;
		}
		elseif (filter_var($doctor, FILTER_VALIDATE_INT) === false)  {
			/** 
			* If doctor is not int 
			* Return false
			**/
			return false;
		}
		elseif (!$this->validateDate($date) || strtotime($date) <= strtotime(date('Y-m-d'))) {
			/** 
			* If date is not valid
			* also date is less than today 
			* Return false
			**/
			return false;
		}
		else {
			return true;
		}
	}
	/** 
	* Validate form input field on server side
	**/
	protected function validateSubmit($data) {
		if (filter_var($data['form_id'], FILTER_VALIDATE_INT) === false) {
			/** 
			* Check form id, Is it int or string 
			* Return false
			**/
			return false;
		} elseif ((strlen(trim($data['name'])) < 1) || (strlen(trim($data['name'])) > 52)) {
			/** 
			* If Last name is not valid ( min 2 character or max 48 ) 
			* Return false
			**/
			return false;
		} elseif ((strlen($data['email']) > 96) || !filter_var($data['email'], FILTER_VALIDATE_EMAIL)) {
			/** 
			* If email is not valid
			* Return false
			**/
			return false;
		} elseif ((strlen($data['mobile']) < 4) || ( strlen($data['mobile']) > 32)) {
			/** 
			* If Mobile number is not valid ( min 4 character or max 32 ) 
			* Return false
			**/
			return false;
		} elseif (filter_var($data['department'], FILTER_VALIDATE_INT) === false) {
			/** 
			* If department is not int 
			* Return false
			**/
			return false;
		} elseif (filter_var($data['doctor'], FILTER_VALIDATE_INT) === false) {
			/** 
			* If doctor is not int 
			* Return false
			**/
			return false;
		} elseif (!$this->validateDate($data['date']) || strtotime($data['date']) <= strtotime(date('Y-m-d'))) {
			/** 
			* If date is not valid
			* also date is less than today 
			* Return false
			**/
			return false;
		} else {
			/** 
			* Everthing looks good
			* Return True
			**/
			return true;
		}
	}
	/** 
	* function to check Date format 
	* If matches then good else invalidate
	**/	
	protected function validateDate($date, $format = 'Y-m-d') {	
		$d = DateTime::createFromFormat($format, $date);
		return $d && $d->format($format) == $date;
	}
}