<?php
/**
* Blog Controller
*/
class BlogController extends Controller
{
	/**
	* Blog controller index method
	* It will call getPage method of this controller
	**/
	public function index() {
		$this->getPage();
	}

	public function singleBlog() {
		if (empty($this->url->get('id'))) {
			$this->url->redirect('blog');
		}
		$this->getSingleBlogPage();
	}

	protected function getPage() 
	{
		/**
		* Intilize common controller
		**/
		$headerController = new CommonController();
		/**
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$header = $headerController->index();
		/**
		* Get Blog page data from DB
		**/
		$this->pageModel = new Pages();
		$page_data= $this->pageModel->pageData('blog');
		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['page_array'] = json_decode($page_data['page_data'], true);
		$data['meta_tag'] = $page_data['meta_tag'];
		$data['meta_description'] = $page_data['meta_description'];
		$data['blogs'] = $this->pageModel->blogs();
		$data['recentblog'] = $this->pageModel->recentBlog();
		$data['trendingblog'] = $this->pageModel->trendingBlog();
		$data['categories'] = $this->pageModel->getCategories();
		$data['active'] = 'blog';
		/**
		* Load home view according to theme selected
		* Pass data to view
		**/
		$this->view->render('blog/'.$header['menu_array']['3']['theme'].'.tpl', $data );
	}

	protected function getSingleBlogPage() 
	{
		/**
		* Intilize common controller
		**/
		$this->headerController = new CommonController();
		/**
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$header = $this->headerController->index();
		/**
		* Get service page data from DB
		**/
		$this->pageModel = new Pages();
		$blog = $this->pageModel->getSingleBlog($this->url->get('id'));
		if ($blog) {
			$data['blog'] = $blog;
		} else {
			$this->url->redirect('blog');
		}
		if (isset($this->session->data['error'])) {
			$data['error'] = $this->session->data['error'];
			unset($this->session->data['error']);
		}
		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
			unset($this->session->data['success']);
		}
		$data['comments'] = $this->pageModel->getComments($this->url->get('id'));
		$data['recentblog'] = $this->pageModel->recentBlog();
		$data['trendingblog'] = $this->pageModel->trendingBlog();
		$data['categories'] = $this->pageModel->getCategories();
		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name'];
		$data['meta_description'] = $blog['title'];
		$data['share_url'] = urlencode("http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]");
		$data['active'] = 'blog';
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$this->view->render('blog/blog.tpl', $data );
	}

	public function commentAction()
	{
		if (isset($_POST['submit']) && !$this->validateField()) {
			$this->session->data['error'] = 'Warning: Please enter valid data in input box to submit comment !!!';
			$this->url->redirect('blog-page&id='.$this->url->post('blog_id'));
			exit();
		}

		$token = $this->url->post('_token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false ) {
			$this->session->data['error'] = 'Warning: Token is not valid. Please try again !!!';
			$this->url->redirect('blog-page&id='.$this->url->post('blog_id'));
			exit();
		}

		$this->formModel = new Forms();
		$result = $this->formModel->createComment($this->url->post, $_SERVER['REMOTE_ADDR']);
		$this->session->data['success'] = 'Success: Comment created successfully.';
		$this->url->redirect('blog-page&id='.$this->url->post('blog_id'));
	}

	protected function validateField()
	{
		if (filter_var($this->url->post('blog_id'), FILTER_VALIDATE_INT) === false) {
			/**
			* If Blog id is not valid or integer 
			* Return false
			**/
			return false;
		} elseif ((strlen(trim($this->url->post('name'))) < 2) || (strlen(trim($this->url->post('name'))) > 52)) {
			/**
			* If Name is not valid ( min 3 character or max 52 ) 
			* Return false
			**/
			return false;
		} elseif ((strlen($this->url->post('email')) > 96) || !filter_var($this->url->post('email'), FILTER_VALIDATE_EMAIL)) {
			/** 
			* If email is not valid
			* Return false
			**/
			return false;
		} elseif ((strlen($this->url->post('content')) < 5)) {
			/** 
			* If Comment content is not valid
			* Return false
			**/
			return false;
		} else {
			/** 
			* Everthing looks good
			* Return True
			**/
			return true;
		}
	}

	public function categoryBlog()
	{
		if (!is_numeric((int)$this->url->get('id'))) {
			$this->url->redirect('blog');
		}
		$id = (int)$this->url->get('id');
		$this->pageModel = new Pages();
		$data['categories'] = $this->pageModel->allCategoryWithChild($id);
		
		if (!empty($data['categories'])) {
			$data['categories'] = array_filter(array_map(function($current){
				return $current['id'];
			},$data['categories']));

			array_push($data['categories'], $id);
			$blogs = $this->pageModel->getBlogByCategory($data['categories']);
		} else {
			$blogs = array();
		}

		/**
		* Intilize common controller
		**/
		$headerController = new CommonController();
		/**
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$header = $headerController->index();
		/**
		* Get Blog page data from DB
		**/
		$this->pageModel = new Pages();
		$page_data= $this->pageModel->pageData('blog');
		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['page_array'] = json_decode($page_data['page_data'], true);
		
		$data['recentblog'] = $this->pageModel->recentBlog();
		$data['trendingblog'] = $this->pageModel->trendingBlog();
		$data['categories'] = $this->pageModel->getCategories();
		$data['blogs'] = $blogs;
		$data['category'] = $this->pageModel->getCategory($id);

		$data['meta_tag'] = $data['category']['name'];
		$data['meta_description'] = $data['category']['name'];
		
		$this->view->render('blog/'.$header['menu_array']['3']['theme'].'.tpl', $data );
	}
}