<?php

/**
* Contact Controller
*/
class ContactController extends Controller
{
	/**
	* Contact controller index method
	* It will call getPage method of this controller
	**/
	public function index() {
		$this->getPage();
	}

	/**
	* Contact controller getpage method
	* This method will get all page data form DB and load view
	**/
	protected function getPage() {
		/**
		* Intilize common controller
		**/
		$headerController = new CommonController();
		/**
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$header = $headerController->index();
		/**
		* Get contact page data from DB
		**/
		$pageModel = new Pages();
		$page_data= $pageModel->pageData('contact');
		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['page_array'] = json_decode($page_data['page_data'], true);
		$data['meta_tag'] = $page_data['meta_tag'];
		$data['meta_description'] = $page_data['meta_description'];
		if (isset($this->session->data['error'])) {
			$data['error'] = $this->session->data['error'];
			unset($this->session->data['error']);
		}
		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
			unset($this->session->data['success']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['active'] = 'contact';
		/**
		* Load contact view
		* Pass data to view
		**/
		$this->view->render( 'contact/contact.tpl', $data );
	}

	public function indexAction() {
		if (!isset($_POST['make-request']) || !$this->validate()) {
			$this->session->data['error'] = 'Warning: Please enter valid details.';
			$this->url->redirect('contact');
		}

		$token = $this->url->post('_token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false ) {
			$this->session->data['error'] = 'Warning: Invalid token. Please try again.';
			$this->url->redirect('contact');
		}

		$data['name'] = $this->url->post('name');
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['subject'] = $this->url->post('subject');
		$data['message'] = $this->url->post('message');
		if (Common::isLoggedIn()) {
			$data['user_id'] = $this->session->data['user_id'];
		} else {
			$data['user_id'] = 0;
		}
		$this->userModel = new User();
		if ($this->userModel->createRequest($data)) {
			$message = file_get_contents(DIR_APP.'views/mail_template/create-request.tpl');
			$message = str_replace('{name}', $data['name'], $message);
			$message = str_replace('{email}', $data['email'], $message);
			$message = str_replace('{mobile}', $data['mobile'], $message);
			$message = str_replace('{subject}', $data['subject'], $message);
			$message = str_replace('{message}', $data['message'], $message);
			$message = str_replace('{site_name}', NAME, $message);
			$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
			$mailer = new Mailer();
			$mailer->mail->setFrom(SITEEMAIL, NAME);
			$mailer->mail->addAddress($data['email'], $data['name']);
			$mailer->mail->isHTML(true);
			$mailer->mail->Subject = 'Request created at '.NAME;
			$mailer->mail->Body = $message;
			$mailer->mail->AltBody = 'Hello '.$data['name'].'.
			Your request has been recieved.'.PHP_EOL.'
			Subject :  '.$data['subject'].'.
			Message :  '.$data['message'];
			$mailer->sendMail();
			$this->session->data['success'] = 'Success: Your request created succefully.';
			$this->url->redirect('contact');
		} else {
			$this->session->data['success'] = 'Error: We could not recieve your request please try after some time!';
			$this->url->redirect('contact');
		}
	}
	/**
	* Validate contact form credentials on server side
	* Validation is also done on client side (Using html5 and javascripts)
	**/
	protected function validate() {
		/** 
		* Check if email and password contains valid phrases
		**/
		if ((strlen($this->url->post('email')) > 96) || !filter_var($this->url->post('email'), FILTER_VALIDATE_EMAIL)) {
			/** 
			* If email is not valid
			* Return false
			**/
			return false;
		} elseif (strlen($this->url->post('name')) < 2) {
			/** 
			* If name is not valid (min 2 character)
			* Return false
			**/
			return false;
		} elseif ((strlen($this->url->post('mobile')) < 4) || (strlen($this->url->post('mobile')) > 32)) {
			/** 
			* If Mobile number is not valid ( min 4 character or max 32 ) 
			* Return false
			**/
			return false;
		} elseif (strlen($this->url->post('subject')) < 5) {
			/** 
			* If Subject is not valid (min 5 character)
			* Return false
			**/
			return false;
		} else {
			return true;
		}
	}
}