<?php

/**
* Home Controller
*/
class ForgotController extends Controller
{
	protected $url;
	/**
	* Forgot controller construct method 
	* it will also called it's parent construct method
	**/
	function __construct() {
		parent::__construct();
		/**
		* Check user is logged in or not
		**/
		if (Common::isLoggedIn()) {
			$this->url->redirect('user/profile');
		}
		/*Intiate Register Model*/
		$this->registerModel = new Register();
	}
	/**
	* Forgot controller index method
	* It will call getPage method of this controller
	**/
	public function index() 
	{
		$this->getPage();
	}

	/**
	* Forgot controller getpage method
	* This method will get all page data form DB and load view
	**/
	protected function getPage()
	{
		/**
		* Intilize common controller
		**/
		$headerController = new CommonController();
		/**
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$header = $headerController->index();
		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name']. '- Forgot Password or Request Password';
		$data['meta_description'] = $header['info_array']['name'];
		if (isset($this->session->data['error'])) {
			$data['error'] = $this->session->data['error'];
			unset($this->session->data['error']);
		}
		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
			unset($this->session->data['success']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['active'] = 'forgot';
		/**
		* Load Forgot view
		* Pass data to view
		**/
		$this->view->render( 'auth/forgot.tpl', $data );
	}

	/**
	* Forgot controller forgot method
	* This method will be called on submit request
	**/
	public function forgot() 
	{
		/**
		* Intilize Url class for post and get request
		**/
		$email = $this->url->post('email');
		/** 
		* Check submit is POST request 
		* Validate input field
        **/
		if (!isset($_POST['forgot']) || !$this->validate($email)) {
			$this->session->data['error'] = 'Warning: Please enter valid data in input box.';
			$this->url->redirect('forgot');
		}

		$token = $this->url->post('_token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false ) {
			$this->session->data['error'] = 'Warning: Invalid token. Please try again.';
			$this->url->redirect('forgot');
		}

		/** 
		* If the user exists
		* Check his account and login attempts
		* Get user data 
        **/
		if ($user = $this->registerModel->checkUser($email)) {
			/** 
			* Check Login attempt
			* The account is locked From too many login attempts 
            **/
			if (!$this->checkLoginAttempts($email)) {
				$this->session->data['error'] = 'Warning: Your account has exceeded allowed number of login attempts. Please try again in 1 hour.';
				$this->url->redirect('login');
			} elseif ( $user['status'] === 1 ) {
				$hash = md5(uniqid(mt_rand(), true));
				$email = $this->url->post('email');
				$this->registerModel->editHash($email, $hash);
				$message = file_get_contents(DIR_APP.'views/mail_template/reset-password.tpl');
				$message = str_replace('{name}', $user['firstname'].' '.$user['lastname'], $message);
				$message = str_replace('{email}', $email, $message);
				$message = str_replace('{code}', $hash, $message);
				$message = str_replace('{site_name}', NAME, $message);
				$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
				$mailer = new Mailer();
				$mailer->mail->setFrom(SITEEMAIL, NAME);
				$mailer->mail->addAddress($email, $user['firstname']);
				$mailer->mail->isHTML(true);
				$mailer->mail->Subject = 'Reset instruction';
				$mailer->mail->Body = $message;
				$mailer->mail->AltBody = 'Hello '.$user['firstname'].'.
				We recently got request to reset your '.NAME.' account password.
				Please click '.URL.DIR_ROUTE.'profile/changepassword&id='.$email.'&code='.$hash.' to reset password.
				If you did not request a paasword reset then contact our support team at '.SITEEMAIL.' ';	
				$mailer->sendMail();
				$this->session->data['success'] = 'Success: Reset instruction sent to your E-mail address.';
				$this->url->redirect('forgot');
			} else {
	        	/** 
	        	* If account is disabled by admin 
		        * Then Show error to user
		        **/
	        	$this->session->data['success'] = 'Success: Your account has disabled by admin, For more info contact us.';
	        	$this->url->redirect('login');
	        }

			/** 
			* User exists now We check if
			* Send Mail to user for reset password
            **/

		} else {
			$this->session->data['error'] = 'Warning: Account does not exists.';
			$this->url->redirect('forgot');
		}
	}

	public function passwordResetPage() 
	{
		$data['email'] = $this->url->get('id');
		$data['hash'] = $this->url->get('code');
		if (empty($data['email']) && empty($data['hash'])) {
			$this->url->redirect('home');
		}
		/**
		* Check Email and Hash value in DB
		**/

		if ($this->registerModel->checkEmailHash($data)) {
			/**
			* Intilize common controller
			**/
			$this->headerController = new CommonController();
			/**
			* Get common data from DB
			* We used header variable to represent common data
			**/
			$header = $this->headerController->index();
			/**
			* Get all data in one array to pass to view
			**/
			$data['header'] = $header;
			$data['meta_tag'] = $header['info_array']['name']. '- Change Password Form';
			$data['meta_description'] = $header['info_array']['name'];
			$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
			/**
			* Load Forgot view
			* Pass data to view
			**/
			$this->view->render( 'user/change-password.tpl', $data );
		} else {

			$this->url->redirect('home');	
		}
	}

	public function passwordReset()
	{
		/** 
		* Check submit is POST request 
		* Validate input field
        **/
		if (!$this->validatePasswordField()) {
			$this->session->data['error'] = 'Warning: Please enter valid data in input box.';
			$this->url->redirect('forgot');
		}

		$token = $this->url->post('_token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false){
			$this->session->data['error'] = 'Warning: Invalid token. Please try again.';
			$this->url->redirect('forgot');
		}
		$data['email'] = $this->url->post('email');
		$data['password'] = $this->url->post('password');
		$data['hash'] = $this->url->post('hash');
		$user = $this->registerModel->checkUser($data['email']);
		if (empty($user)) {
			$this->url->redirect('home');
		}
		if ($this->registerModel->changepassword($data)) {
			$message = file_get_contents(DIR_APP.'views/mail_template/reset-password-success.tpl');
			$message = str_replace('{name}', $user['firstname'].' '.$user['lastname'], $message);
			$message = str_replace('{site_name}', NAME, $message);
			$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
			$mailer = new Mailer();
			$mailer->mail->setFrom(SITEEMAIL, NAME);
			$mailer->mail->addAddress($user['email'], $user['firstname']);
			$mailer->mail->isHTML(true);
			$mailer->mail->Subject = 'Password Changed Confirmation';
			$mailer->mail->Body = $message;
			$mailer->mail->AltBody = 'Hello '.$user['firstname'].PHP_EOL.' '.$user['lastname'].' Your account password has been change succesfully.'.PHP_EOL.' If you didnot change your password than contact us at '.URL.' ';	
			$mailer->sendMail();
			$this->session->data['success'] = 'Success : Password changed successfully. Login with new password.';
			$this->url->redirect('login');
		} else {
			$this->session->data['error'] = 'Warning : Password could not be changed successfully. Please try again.';
			$this->url->redirect('login');	
		}
	}

	/** 
	* Validate input field on server side
	* Check if email and password contains valid phrases
	**/
	protected function validate($email)
	{
		if ((strlen($email) > 96) || !filter_var($email, FILTER_VALIDATE_EMAIL)) {
			/** 
			* If email is not valid
			* Return false
			**/
			return false;
		} else {
			/** 
			* If email looks good
			* Return true for further info
			**/
			return true;
		}
	}

	public function validatePasswordField()
	{
		if ((strlen($this->url->post('email')) > 96) || !filter_var($this->url->post('email'), FILTER_VALIDATE_EMAIL)) {
			/** 
			* If email is not valid
			* Return false
			**/
			return false;
		} elseif (strlen($this->url->post('password')) < 6) {
			/** 
			* If Password is not valid ( min 6 character ) 
			* Return false
			**/
			return false;
		} elseif ($this->url->post('password') != $this->url->post('confirmpassword')) {
			/** 
			* If Password does not match with confirmpassword 
			* Return false
			**/
			return false;
		} else {
			/** 
			* Everything looks good 
			* Return True
			**/
			return true;
		}
	}

	/** 
	* Check login attempts of user for brute force attacks 
	**/
	protected function checkLoginAttempts($email)
	{
		/**
		* Get attempts from DB and check with predefined field
		* All login attempts are counted from the past 1 hours. 
		**/
		$this->loginModel = new Login();
		$login_attempts = $this->loginModel->checkAttempts($email);
		if ($login_attempts && ($login_attempts['count'] >= 4) && strtotime('-1 hour') < strtotime($login_attempts['date_modified'])) {
			return false;
		} else {
			return true;
		}
	}
}