<?php

/**
* Login Controller
*/
class LoginController extends Controller
{
	protected $url;
	/**
	* Login controller construct method 
	* it will also called it's parent construct method
	**/
	function __construct() 
	{
		parent::__construct();
		/**
		* Check user is logged in or not
		**/
		if (Common::isLoggedIn()) {
			$this->url->redirect('user/profile');
		}
	}

	/**
	* Login controller index method
	* It will call getPage method of this controller
	**/
	public function index()
	{
		$this->getPage();
	}

	/**
	* Login controller getpage method
	* This method will get all page data form DB and load view
	**/
	protected function getPage()
	{	
		/**
		* Intilize common controller
		**/
		$headerController = new CommonController();
		/**
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$header = $headerController->index();
		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name']. '- Login';
		$data['meta_description'] = $header['info_array']['name'];
		if (isset($this->session->data['error'])) {
			$data['error'] = $this->session->data['error'];
			unset($this->session->data['error']);
		}
		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
			unset($this->session->data['success']);
		}

		if (isset($_SERVER['HTTP_REFERER']) && !empty($_SERVER['HTTP_REFERER'])) {
			$this->session->data['refferal'] = $_SERVER['HTTP_REFERER'];
		}

		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['active'] = 'login';
		/**
		* Load login view
		* Pass data to view
		**/
		$this->view->render( 'auth/login.tpl', $data );
	}

	/**
	* Login controller login method
	* This method will call on login submit action
	**/
	public function login()
	{
		/**
		* Intilize Url class for post and get request
		**/
		
		unset($this->session->data['user_id']);
		unset($this->session->data['login_token']);
		/** 
		* Check submit is POST request 
		* Validaate input field
        **/
		if (!$this->validate()) {
			$this->session->data['error'] = 'Warning: Please enter valid data in input box.';
			$this->url->redirect('login');
		}
		$token = $this->url->post('_token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false) {
			$this->session->data['error'] = 'Warning: Invalid token. Please try again.';
			$this->url->redirect('login');
		}
		/*Intiate login Model*/
		$this->loginModel = new Login();
		/**
		* If the user exists
		* Check his account and login attempts
		* Get user data 
        **/
		$email = $this->url->post('email');
		$password = $this->url->post('password');
		if ($user = $this->loginModel->checkUser($email)) {
			/** 
			* User exists now We check if
			* The account is locked From too many login attempts 
            **/
			if (!$this->checkLoginAttempts($email)) {
				$this->session->data['error'] = 'Warning: Your account has exceeded allowed number of login attempts. Please try again in 1 hour.';
				$this->url->redirect('login');
			} elseif ($user['status'] === 1) {
	            /** 
	            * Check if the password in the database matches the password user submitted.
	            * We are using the password_verify function to avoid timing attacks.
	            **/
	            if (password_verify( $password, $user['password'])) {
	            	$this->loginModel->deleteAttempt($email);
	            	/** 
	            	* Start session for user create session varible 
		            * Create session login string for authentication
		            **/
	            	$this->session->data['user_id'] = preg_replace("/[^0-9]+/", "", $user['user_id']); 
	            	$this->session->data['login_token'] = hash('sha512', AUTH_KEY . LOGGED_IN_SALT);
	            	
	            	if (isset($this->session->data['refferal'])) {
	            		if (headers_sent()) {
	            			echo '<script>window.location ='. $this->session->data['refferal'] .'</script>';
	            		}
	            		else {
	            			header('location: '. $this->session->data['refferal'] , true);
	            		}
	            		exit();
	            	} else {
	            		$this->url->Redirect('user/appointment');
	            	}
	            	
	            } else {
	            	/** 
	            	* Add login attemt to Db
		            * Redirect back to login page
		            * Set error for user
		            **/
	            	$this->loginModel->addAttempt($email);
	            	$this->session->data['error'] = 'Warning: No match for E-Mail Address and/or Password.';
	            	$this->url->Redirect('login');
	            }
	        } else {
	        	/** 
	        	* If account is disabled by admin 
		        * Then Show error to user
		        **/
	        	$this->session->data['error'] = 'Warning: Your account has disabled for more info contact us.';
	        	$this->url->redirect('login');
	        }
	    } else {
	    	/** 
	        * If email address not found in DB 
		    * Show error to user for creating account
		    **/
	    	$this->session->data['error'] = 'Warning: No match for E-Mail Address and/or Password.';
	    	$this->url->redirect('login');
	    }
	}

	/**
	* Validate login credentials on server side
	* Validation is also done on client side (Using html5 and javascripts)
	**/
	protected function validate()
	{
		/** 
		* Check if email and password contains valid phrases
		**/
		if ((strlen($this->url->post('email')) > 96) || !filter_var($this->url->post('email'), FILTER_VALIDATE_EMAIL)) {
			/** 
			* If email is not valid
			* Return false
			**/
			return false;
		} elseif (strlen($this->url->post('password')) < 6) {
			/** 
			* If password is not valid or minimum 6 character
			* Return false
			**/
			return false;
		} else {
			return true;
		}
	}

	/** 
	* Check login attempts of user for brute force attacks 
	**/
	protected function checkLoginAttempts($email) 
	{
		/**
		* Get attempts from DB and check with predefined field
		* All login attempts are counted from the past 1 hours. 
		**/
		$login_attempts = $this->loginModel->checkAttempts($email);
		if ($login_attempts && ($login_attempts['count'] >= 4) && strtotime('-1 hour') < strtotime($login_attempts['date_modified'])) {
			return false;
		} else {
			return true;
		}
	}
}