<?php

/**
* PaymentController
*/
class PaymentController extends Controller
{
	private $user_id;
	function __construct() 
	{
		parent::__construct();
		/**
		* Check user is logged in or not
		* If logged in than get user_id from session varible
		**/
		if (Common::isLoggedIn()) {
			$this->user_id = $this->session->data['user_id'];
		} else {
			/**
			* If user is not logged in
			* Then redirect to login page
			**/
			$this->url->redirect('login');
		}
	}
	public function makePayment()
	{
		$id = (int)$this->url->get('invoice');
		if (empty($id) || !is_int($id)) {
			$this->url->redirect('user/invoices');
		}
		//$data['paypalID'] = 'paarth@iesightdesign.studio';
		//$data['paypalID'] = 'thakurmahendra13@gmail.com';
		$data['cancel'] = URL.DIR_ROUTE.'cancel';
		$data['success'] = URL.DIR_ROUTE.'successpayment';

		$paymentModel = new Payment();
		$paymentData = json_decode($paymentModel->getPaymentData(), true);

		if ($paymentData['status'] == "0") {
			$this->url->redirect('user/invoices');
		}

		$data['token'] = $this->token_generator(64);
		$this->session->data['payment_token'] = $data['token'];

		if (!empty($paymentData['username'])) {
			$data['paypalID'] = $paymentData['username'];
		} else {
			echo "Online Payment Gateway is disabled.";
			exit();
		}

		if ($paymentData['mode'] == "1") {
			$data['paypalURL'] = 'https://www.paypal.com/cgi-bin/webscr';
		} else {
			$data['paypalURL'] = 'https://www.sandbox.paypal.com/cgi-bin/webscr';
		}

		$data['result'] = $paymentModel->getInvoiceData($this->url->get('invoice'));


		if ($data['result']['due'] <= "0") {
			$this->url->redirect('user/invoices');
		}

		//Get basic Info
		$info = $paymentModel->getInfo();
		/**
		* Load Launguge
		**/
		if (!empty($info['language'])) {
			require(DIR_BUILDER.'language/'.$info['language'].'/payment.php');
		} else {
			require(DIR_BUILDER.'language/eng/payment.php');
		}
		
		$data['lang'] = $lang;

		/*Render User list view*/
		$this->view->render('payment/make_payment.tpl', $data);
	}

	public function cancelPayment()
	{
		$data = NULL;
		
		//Get basic Info
		$paymentModel = new Payment();
		$info = $paymentModel->getInfo();
		/**
		* Load Launguge
		**/
		if (!empty($info['language'])) {
			require(DIR_BUILDER.'language/'.$info['language'].'/payment.php');
		} else {
			require(DIR_BUILDER.'language/eng/payment.php');
		}
		
		$data['lang'] = $lang;
		/*Render User list view*/
		$this->view->render('payment/cancel.tpl', $data);
	}

	public function successPayment()
	{
		$data = $this->url->post;

		if ( isset($this->session->data['payment_token']) && $data['custom'] != $this->session->data['payment_token']) {
			$this->url->redirect('cancel');
		}

		unset($this->session->data['payment_token']);

		$paymentModel = new Payment();
		$checkTxnId = $paymentModel->checkTxnId($data['txn_id']);
		$paymentData = json_decode($paymentModel->getPaymentData(), true);
		
		if (!empty($checkTxnId)) {
			$this->url->redirect('cancel');
		}

		if ($data['business'] != $paymentData['username']) {
			$this->url->redirect('cancel');	
		}

		if ($data['payment_status'] != "Completed") {
			
			$this->url->redirect('cancel');	
		}

		$data['payment_date'] = date_format(date_create($data['payment_date']), 'Y-m-d H:i:s');

		$invoiceData = $paymentModel->getInvoiceData($data['item_number']);

		$result = $paymentModel->createPayment($data);

		$invoiceData['due'] = (int)$invoiceData['due'] - $data['payment_gross'];
		$invoiceData['paid'] = (int)$invoiceData['paid'] + $data['payment_gross'];
		$invoiceData['id'] = $data['item_number'];
		if ($invoiceData['due'] > .9) {
			$invoiceData['status'] = "Partially Paid";
		} else {
			$invoiceData['status'] = "Paid";
		}


		$result = $paymentModel->updateInvoiceAmount($invoiceData);

		$message = file_get_contents(DIR_APP.'views/mail_template/invoice-paid.tpl');
		$message = str_replace('{name}', $invoiceData['name'], $message);
		$message = str_replace('{invoice_id}', $data['item_number'], $message);
		$message = str_replace('{txn_id}', $data['txn_id'], $message);
		$message = str_replace('{payment_date}', $data['payment_date'], $message);
		$message = str_replace('{paid}', $data['mc_currency'].' '.$data['payment_gross'], $message);
		$message = str_replace('{site_name}', NAME, $message);
		$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
		$mailer = new Mailer();
		$mailer->mail->setFrom(SITEEMAIL, NAME);
		$mailer->mail->addAddress($invoiceData['email'], $invoiceData['name']);
		$mailer->mail->isHTML(true);
		$mailer->mail->Subject = 'Payment Reciept';
		$mailer->mail->Body = $message;
		$mailer->mail->AltBody = 'Hello '.$invoiceData['name'].'.
		Your Invoice has been Paid on '.$data['payment_date'].'.
		Your Invoice ID : '.$data['item_number'].'';
		$mailer->sendMail();

		$this->session->data['txn_id'] = $data['txn_id'];
		$this->url->redirect('success');
	}

	public function success()
	{
		$data = array();
		if (!isset($this->session->data['txn_id'])) {
			$this->url->redirect('home');
		}
		$data['txn_id'] = $this->session->data['txn_id'];
		unset($this->session->data['txn_id']);
		
		//Get basic Info
		$paymentModel = new Payment();
		$info = $paymentModel->getInfo();
		/**
		* Load Launguge
		**/
		if (!empty($info['language'])) {
			require(DIR_BUILDER.'language/'.$info['language'].'/payment.php');
		} else {
			require(DIR_BUILDER.'language/eng/payment.php');
		}
		
		$data['lang'] = $lang;
		/*Render User list view*/
		$this->view->render('payment/success.tpl', $data);
	}

	private function token_generator( $length = 64 ) {
        $token = "";
        $charArray = str_split("ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789abcdefghijklmnopqrstuvwxyz");
        for($i = 0; $i < $length; $i++){
            $randItem = array_rand($charArray);
            $token .= "".$charArray[$randItem];
        }
        return $token;
    }

}