<?php

/**
* Home Controller
*/
class RegisterController extends Controller
{
	protected $url;
	/**
	* Register controller construct method 
	* it will also called it's parent construct method
	**/
	function __construct() 
	{
		parent::__construct();
		/**
		* Check user is logged in or not
		**/
		if (Common::isLoggedIn()) {
			$this->url->redirect('user/profile');
		}
		/*Intiate Register Model*/
		$this->registerModel = new Register();
	}
	/**
	* Register Controller index method
	* It will call getPage method
	**/
	public function index() 
	{
		$this->getPage();
	}

	/**
	* Register controller forgot method
	* This method will be called on submit request
	**/
	protected function getPage() 
	{
		/**
		* Intilize common controller
		**/
		$this->headerController = new CommonController();
		/**
		* Get Coomon data from DB
		* We user header variable to represent common data
		**/
		$header = $this->headerController->index();
		/**
		* Get all data in
		**/
		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name']. '- Create Account';
		$data['meta_description'] = $header['info_array']['name'];
		if (isset($this->session->data['error'])) {
			$data['error'] = $this->session->data['error'];
			unset($this->session->data['error']);
		}
		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
			unset($this->session->data['success']);
		}
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['active'] = 'register';
		/**
		* Load register view
		* Pass data to view
		**/
		$this->view->render( 'auth/register.tpl', $data );
	}

	/**
	* Register method
	* It will call on Register submit
	**/
	public function register() 
	{
		/**
		* Intilize Url class for post and get request
		**/
		$data = array(
			'firstname' => $this->url->post('firstname'),
			'lastname' => $this->url->post('lastname'),
			'email' => $this->url->post('email'),
			'mobile' => $this->url->post('mobile'),
			'password' => $this->url->post('password'),
			'confirmpassword' => $this->url->post('confirmpassword')
			);
		/** 
		* Check submit is POST request 
		* Validaate input field
        **/

		if (!isset($_POST['register']) || !$this->validate($data)) {
			$this->session->data['error'] = 'Warning: Please enter valid data.';
			$this->url->redirect('register');
		}

		$token = $this->url->post('_token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false) {
			$this->session->data['error'] = 'Warning: Invalid token. Please try again.';
			$this->url->redirect('register');
		}

		/*Intiate login Model*/
		/** 
		* Check if user already registerd or not
		* If the user exists Show error 
        **/
		if ($user = $this->registerModel->checkUser($data['email'])) { 
			$this->session->data['error'] = 'Warning: Account already exist. Login Now';
			$this->url->redirect('login');
		} else {
			/**
			* Unique hash value for email verification
			**/
			$temp_hash = md5(uniqid(mt_rand(), true));
			/**
			* Create user account
			* Insert value in DB
			**/
			$user = $this->registerModel->createAccout($data, $temp_hash);
			$message = file_get_contents(DIR_APP.'views/mail_template/create-user.tpl');
			$message = str_replace('{name}', $data['firstname'].' '.$data['lastname'], $message);
			$message = str_replace('{email}', $data['email'], $message);
			$message = str_replace('{code}', $temp_hash, $message);
			$message = str_replace('{site_name}', NAME, $message);
			$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
			$mailer = new Mailer();
			$mailer->mail->setFrom(SITEEMAIL, NAME);
			$mailer->mail->addAddress($data['email'], $data['firstname']);
			$mailer->mail->isHTML(true);
			$mailer->mail->Subject = 'Account created with '.NAME.', please verify';
			$mailer->mail->Body = $message;
			$mailer->mail->AltBody = 'Hello '.$data['firstname'].'.
			Welcome to '.URL. PHP_EOL.'Thanks for creating an account with us.
			If you have not created this account then contact our support team at '.SITEEMAIL.'.';
			$mailer->sendMail();
			/**
			* Set success message 
			* Redirect to login page for login
			**/
			$this->session->data['success'] = 'Success: Account created succefully, check your mail for more info. Login Now';
			$this->url->redirect('login');
		}
	}

	public function userVerfiy() 
	{
		$data['email'] = $this->url->get('id');
		$data['hash'] = $this->url->get('code');

		if ((strlen($data['email']) > 96) || !filter_var($data['email'], FILTER_VALIDATE_EMAIL)) {
			$this->url->redirect('home');
		} elseif (empty($data['hash'])) {
			$this->url->redirect('home');
		}

		if ($this->registerModel->checkEmailHash($data)) {
			$confirmAccount = $this->registerModel->confirmAccount($data);
			$this->session->data['success'] = 'Your Email address has been confirmed. Login now.';
			$this->url->redirect('login');
		} else {
			$this->url->redirect('login');
		}
	}

	/**
	* Validate Register data on server side
	* Validation is also done on client side (Using html5 and javascripts)
	**/
	protected function validate($data) {
		/** 
		* Validate input field on server side
		* Check if email and password contains valid phrases
		**/
		if ((strlen(trim($data['firstname'])) < 2) || (strlen(trim($data['firstname'])) > 48)) {
			/** 
			* If First name is not valid ( min 2 character or max 48 ) 
			* Return false
			**/
			return false;
		} elseif ((strlen(trim($data['lastname'])) < 1) || (strlen(trim($data['lastname'])) > 48)) {
			/** 
			* If Last name is not valid ( min 2 character or max 48 ) 
			* Return false
			**/
			return false;
		} elseif ((strlen($data['email']) > 96) || !filter_var($data['email'], FILTER_VALIDATE_EMAIL)) {
			/** 
			* If email is not valid
			* Return false
			**/
			return false;
		} elseif ((strlen($data['mobile']) < 4) || (strlen($data['mobile']) > 32)) {
			/** 
			* If Mobile number is not valid ( min 4 character or max 32 ) 
			* Return false
			**/
			return false;
		} elseif (strlen($data['password']) < 6) {
			/** 
			* If Password is not valid ( min 6 character ) 
			* Return false
			**/
			return false;
		} elseif ($data['confirmpassword'] != $data['password']) {
			/** 
			* If Password does not match with confirmpassword 
			* Return false
			**/
			return false;
		} else {
			/** 
			* Everything looks good 
			* Return True
			**/
			return true;
		}
	}
}