<?php

/**
* Service Controller
*/
class ServiceController extends Controller
{
	/**
	* Service controller index method
	* It will call getPage method of this controller
	**/
	public function index() 
	{
		$this->getPage();
	}

	public function singleService() 
	{
		if (empty($this->url->get('id'))) {
			$this->url->redirect('services');
		}
		$this->getSingleServicePage();
	}
	/**
	* Service controller getpage method
	* This method will get all page data form DB and load view
	**/
	protected function getPage() 
	{
		/**
		* Intilize common controller
		**/
		$this->headerController = new CommonController();
		/**
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$header = $this->headerController->index();
		/**
		* Get service page data from DB
		**/
		$this->pageModel = new Pages();
		$page_data = $this->pageModel->pageData('service');
		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['page_array'] = json_decode($page_data['page_data'], true);
		$data['meta_tag'] = $page_data['meta_tag'];
		$data['meta_description'] = $page_data['meta_description'];
		$data['services'] = $this->pageModel->allServices();
		$data['facilities'] = $this->pageModel->allFacilities();
		$data['recentblog'] = $this->pageModel->recentBlog();
		$data['slider_doctor'] = $this->pageModel->getSliderDoctors();
		$data['active'] = 'service';
		/**
		* Load service-list view according to theme selected
		* Pass data to view
		**/
		$this->view->render('service/'.$header['menu_array']['1']['theme'].'.tpl', $data );
	}

	protected function getSingleServicePage() 
	{
		$id = (int)$this->url->get('id');
		if (!is_numeric($id) || empty($id)) {
			$this->url->redirect('services');
		}
		
		/**
		* Get service page data from DB
		**/
		$this->pageModel = new Pages();
		$service = $this->pageModel->getSingleService($id);
		if ($service) {
			$data['service'] = $service;
		} else {
			$this->url->redirect('services');
		}
		/**
		* Intilize common controller
		**/
		$this->headerController = new CommonController();
		/**
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$header = $this->headerController->index();
		if (isset($this->session->data['error'])) {
			$data['error'] = $this->session->data['error'];
			unset($this->session->data['error']);
		}
		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
			unset($this->session->data['success']);
		}
		$data['services'] = $this->pageModel->allServices();
		$data['reviews'] = $this->pageModel->allServiceReviews($id);
		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name'];
		$data['meta_description'] = $service['name'];
		$data['active'] = 'service';
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$this->view->render('service/service.tpl', $data );
	}

	public function reviewAction()
	{
		if (isset($_POST['submit']) && !$this->validateField()) {
			$this->session->data['error'] = 'Warning: Please enter valid data in input box to submit review !!!';
			$this->url->redirect('serivce&id='.$this->url->post('review_for_id'));
			exit();
		}

		$token = $this->url->post('_token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false ) {
			$this->session->data['error'] = 'Warning: Token is not valid. Please try again !!!';
			$this->url->redirect('serivce&id='.$this->url->post('blog_id'));
			exit();
		}

		$this->formModel = new Forms();
		$result = $this->formModel->createReview($this->url->post, $_SERVER['REMOTE_ADDR']);
		$this->session->data['success'] = 'Success: Review created successfully.';
		$this->url->redirect('service&id='.$this->url->post('review_for_id'));
	}

	protected function validateField()
	{
		if (filter_var($this->url->post('review_for_id'), FILTER_VALIDATE_INT) === false) {
			/**
			* If Blog id is not valid or integer 
			* Return false
			**/
			return false;
		} elseif ((strlen(trim($this->url->post('name'))) < 2) || (strlen(trim($this->url->post('name'))) > 52)) {
			/**
			* If Name is not valid ( min 3 character or max 52 ) 
			* Return false
			**/
			return false;
		} elseif ((strlen($this->url->post('email')) > 96) || !filter_var($this->url->post('email'), FILTER_VALIDATE_EMAIL)) {
			/** 
			* If email is not valid
			* Return false
			**/
			return false;
		} elseif ((strlen($this->url->post('content')) < 5)) {
			/** 
			* If Comment content is not valid
			* Return false
			**/
			return false;
		} else {
			/** 
			* Everthing looks good
			* Return True
			**/
			return true;
		}
	}
}