<?php

/**
* User Controller
*/
class UserController extends Controller {
	/**
	* User controller construct method 
	* it will also called it's parent construct method
	**/
	private $user_id;
	function __construct() 
	{
		parent::__construct();
		/**
		* Check user is logged in or not
		* If logged in than get user_id from session varible
		**/
		if (Common::isLoggedIn()) {
			$this->user_id = $this->session->data['user_id'];
		} else {
			/**
			* If user is not logged in
			* Then redirect to login page
			**/
			$this->url->redirect('login');
		}
		/**
		* Intilize User Model
		**/
		$this->userModel = new User();
	}

	public function appointment() 
	{
		/**
		* Intilize common controller
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$this->headerController = new CommonController();
		$header = $this->headerController->index();
		/**
		* Intilize User Model
		* Get all appointment from DB
		**/
		
		$data['appointments'] = $this->userModel->getAppointment($header['user']['email'], $this->user_id);
		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name']. '- My Appointment';
		$data['meta_description'] = $header['info_array']['name'];
		
		$data['doctorlist'] = $this->userModel->doctors();
		$data['active'] = 'appointment';
		/**
		* Load my appointment view
		* Pass data to view
		**/
		$this->view->render('user/appointment.tpl', $data);
	}

	public function appointmentView()
	{
		$id = $this->url->get('id');
		if (empty($id)) {
			$this->url->redirect('user/appointment');
		}

		/**
		* Intilize common controller
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$this->headerController = new CommonController();
		$header = $this->headerController->index();
		/**
		* Intilize User Model
		* Get all appointment from DB
		**/

		$data['appointment'] = $this->userModel->getAppointmentView($header['user']['email'], $id);
		if (empty($data['appointment'])) {
			$this->url->redirect('user/appointment');
		}
		$data['prescription'] = $this->userModel->checkPrescription($id);
		$data['reports'] = $this->userModel->getReports($id);

		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name']. '- My Appointment';
		$data['meta_description'] = $header['info_array']['name'];
		
		$data['doctorlist'] = $this->userModel->doctors();
		$data['active'] = 'appointment';

		$data['fancybox'] = 1;
		/**
		* Load my appointment view
		* Pass data to view
		**/
		$this->view->render('user/appointment_view.tpl', $data);
	}

	public function prescription()
	{
		$id = $this->url->get('id');
		if (empty($id)) {
			$this->url->redirect('user/appointment');
		}
		/**
		* Intilize common controller
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$this->headerController = new CommonController();
		$header = $this->headerController->index();
		/**
		* Intilize User Model
		* Get prescription from DB
		**/
		$data['result'] = $this->userModel->getPrescription($header['user']['email'], $id);
		$data['doctor_data'] = json_decode($data['result']['about'], true);
		

		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name']. '- Prescription';
		$data['meta_description'] = $header['info_array']['name'];

		/**
		* Load my prescription view
		* Pass data to view
		**/
		$this->view->render('user/prescription.tpl', $data);
	}

	/**
	* Request method for my request page
	**/
	public function request()
	{
		/**
		* Intilize common controller
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$this->headerController = new CommonController();
		$header = $this->headerController->index();
		
		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name']. '- My Request';
		$data['meta_description'] = $header['info_array']['name'];
		$data['request'] = $this->userModel->getRequest($header['user']['email'], $this->user_id);
		$data['active'] = 'request';
		
		/**
		* Load my appointment view
		* Pass data to view
		**/
		$this->view->render('user/request.tpl', $data);
	}

	/**
	* Profile method for my profile page
	**/
	public function profile()
	{
		$data = $this->userData();
		$this->view->render('user/profile.tpl', $data);
	}

	/**
	* Profile edit method for profile edit page
	**/
	public function profileEdit() 
	{
		$data = $this->userData();
		/**
		* Load my appointment view
		* Pass data to view
		**/
		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
		} 
		if (isset($this->session->data['error'])) {
			$data['error'] = $this->session->data['error'];
		}

 		$this->view->render('user/edit-profile.tpl', $data);
	}

	public function profileUpdate()
	{
		if (!$this->validateProfile()) {
			$_SERVER['ERROR'] = 'Please enter valid data input';
			$this->url->redirect('user/profile/edit');
		}
		$token = $this->url->post('_token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false) {
			$this->session->data['error'] = 'Warning: Invalid token. Please try again.';
			$this->url->redirect('user/profile/edit');
		}
		$data['email'] = $this->url->post('email');
		$data['mobile'] = $this->url->post('mobile');
		$data['dob'] = $this->url->post('dob');
		$data['gender'] = $this->url->post('gender');
		$data['bloodgroup'] = $this->url->post('bloodgroup');
		$data['location'] = $this->url->post('location');
		$data['country'] = $this->url->post('country');
		$data['user_id'] = $this->session->data['user_id'];
		$data['active'] = 'profile';
		if ($this->userModel->checkUserEmail($data)) {
			$result = $this->userModel->updateUser($data);
			$this->session->data['success'] = 'Success : Your Profile updated succefully.';
			$this->url->redirect('user/profile/edit');
		} else {
			$this->session->data['error'] = 'Error : Please enter valid data in input field.';
			$this->url->redirect('user/profile/edit');
		}
	}

	public function profileUpdatePassword() 
	{
		if (!$this->validateProfilePassword()) {
			$this->session->data['error'] = 'Please enter valid password in input field';
			$this->url->redirect('user/profile/edit');
		}
		$token = $this->url->post('_token');
		$token_check = hash('sha512', TOKEN . TOKEN_SALT);
		if (hash_equals($token_check, $token) === false) {
			$this->session->data['error'] = 'Warning: Invalid token. Please try again.';
			$this->url->redirect('user/profile/edit');
		}

		$data['user_id'] = $this->session->data['user_id'];
		$data['email'] = $this->url->post('email');
		$data['old'] = $this->url->post('oldpassword');
		$data['new'] = $this->url->post('newpassword');
		$user = $this->userModel->getPassword($data);
		if (password_verify( $data['old'], $user['password'])) {
			$result = $this->userModel->updatePassword($data);
			$message = file_get_contents(DIR_APP.'views/mail_template/reset-password-success.tpl');
			$message = str_replace('{name}', $user['firstname'].' '.$user['lastname'], $message);
			$message = str_replace('{site_name}', NAME, $message);
			$message = str_replace('{site_link}', URL.DIR_ROUTE, $message);
			$mailer = new Mailer();
			$mailer->mail->setFrom(SITEEMAIL, NAME);
			$mailer->mail->addAddress($user['email'], $user['firstname']);
			$mailer->mail->isHTML(true);
			$mailer->mail->Subject = 'Password Changed Confirmation';
			$mailer->mail->Body = $message;
			$mailer->mail->AltBody = 'Hello '.$user['firstname'].PHP_EOL.' Your account password has been change succesfully.'.PHP_EOL.' If you didnot change your password than contact us at '.URL.' ';	
			$mailer->sendMail();
			$this->session->data['success'] = 'Success: Account Password updated successfully.';
			$this->url->Redirect('user/profile/edit');   
		} else {
			$this->session->data['error'] = 'Warning: Old Password is Wrong.';
			$this->url->Redirect('user/profile/edit');
		}
	}

	/**
	* Common method to load data in profile or profile edit method
	**/
	protected function userData() 
	{
		/**
		* Intilize common controller
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$this->headerController = new CommonController();
		$header = $this->headerController->index();
		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name']. '- My Profile';
		$data['meta_description'] = $header['info_array']['name'];
		$data['user_data'] = $this->userModel->getUserData($this->user_id);
		$data['token'] = hash('sha512', TOKEN . TOKEN_SALT);
		$data['active'] = 'profile';
		if (!empty($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
			unset($this->session->data['success']);
		}
		if (!empty($this->session->data['error'])) {
			$data['error'] = $this->session->data['error'];
			unset($this->session->data['error']);
		}
		return $data;
	}

	public function getInvoices()
	{
		/**
		* Intilize common controller
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$this->headerController = new CommonController();
		$header = $this->headerController->index();
		
		/**
		* Get all data in one array to pass to view
		**/
		$data['header'] = $header;
		$data['meta_tag'] = $header['info_array']['name']. '- My Invoices';
		$data['meta_description'] = $header['info_array']['name'];
		$data['invoices'] = $this->userModel->invoices($header['user']['email'], $this->user_id);
		$data['active'] = 'invoices';
		/**
		* Load my appointment view
		* Pass data to view
		**/
		$this->view->render('user/invoices_list.tpl', $data);
	}

	public function invoice() 
	{
		$invoice_id = $this->url->get('invoice');
		if (empty($invoice_id)) {
			$this->url->redirect('user/appointment');
		}
		/**
		* Intilize common controller
		* Get common data from DB
		* We used header variable to represent common data
		**/
		$this->headerController = new CommonController();
		$header = $this->headerController->index();
		/**
		* Get invoice data from DB
		**/
		$invoice = $this->userModel->getInvoice($invoice_id);

		if (empty($invoice)) {
			$this->url->redirect('user/invoices');
		}
		
		$data['header'] = $header;
		$data['result'] = $invoice;
		$data['items'] = json_decode($invoice['item'], true);
		
		$this->view->render( 'user/invoice.tpl', $data );
	}

	protected function validateProfile() 
	{
		if ((strlen(trim($this->url->post('firstname'))) < 1) || (strlen(trim($this->url->post('firstname'))) > 52)) {
			/** 
			* If Last name is not valid ( min 2 character or max 48 ) 
			* Return false
			**/
			return false;
		} elseif ((strlen(trim($this->url->post('lastname'))) < 1) || (strlen(trim($this->url->post('lastname'))) > 52)) {
			/** 
			* If Last name is not valid ( min 2 character or max 48 ) 
			* Return false
			**/
			return false;
		} elseif ((strlen($this->url->post('email')) > 96) || !filter_var($this->url->post('email'), FILTER_VALIDATE_EMAIL)) {
			/** 
			* If email is not valid
			* Return false
			**/
			return false;
		} else {
			return true;
		}
	}

	public function validateProfilePassword()
	{
		if (strlen($this->url->post('newpassword')) < 6) {
			/** 
			* If Password is not valid ( min 6 character ) 
			* Return false
			**/
			return false;
		} elseif ($this->url->post('newpassword') != $this->url->post('confirmpassword')) {
			/** 
			* If Password does not match with confirmpassword 
			* Return false
			**/
			return false;
		} else {
			return true;
		}
	}
}