<?php

/**
* Pages Model
*/
class Pages extends Model
{
	public function pageData($page_name)
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "page` WHERE `page_name` = ? LIMIT 1 ", array($this->model->escape($page_name)));
		if ($query->num_rows > 0) {
			return $query->row;
		} else {
			return false;
		}
	}

	public function doctors()
	{
		$query = $this->model->query("SELECT `name`, `picture`, `about`, `social`, `priority` FROM `" . DB_PREFIX . "doctor` ORDER BY `priority` ASC LIMIT 3");
		return $query->rows;
	}

	public function testimonials() 
	{ 
		$query = $this->model->query("SELECT `name`, `picture`, `testimonial` FROM `" . DB_PREFIX . "testimonial` WHERE `status` = ? ", array(1));
		return $query->rows;
	}

	public function blogs() 
	{
		$query = $this->model->query("SELECT `id`, `title`, `picture`, `short_post`, `author`, `date_of_joining` AS `date` FROM `" . DB_PREFIX . "blog` WHERE `status` = ? ORDER BY `date_of_joining` DESC " , array(1));
		return $query->rows;
	}

	public function recentBlog() 
	{
		$query = $this->model->query("SELECT `id`, `title`, `picture`, `date_of_joining` FROM `" . DB_PREFIX . "blog` WHERE `status` = ? ORDER BY `date_of_joining` DESC LIMIT 5", array(1));
		return $query->rows;
	}

	public function getSliderDoctors()
	{
		$query = $this->model->query("SELECT `id`, `name`, `picture`, `about` FROM `" . DB_PREFIX . "doctor` WHERE `status` = ? ORDER BY `priority` ASC LIMIT 6", array(1));
		return $query->rows;
	}

	public function getSliderServices()
	{
		$query = $this->model->query("SELECT `id`, `name`, `picture` FROM `" . DB_PREFIX . "service` WHERE `status` = ? ORDER BY `priority` ASC LIMIT 6", array(1));
		return $query->rows;
	}

	public function trendingBlog()
	{
		$query = $this->model->query("SELECT `id`, `title`, `picture`, `hits`, `date_of_joining` FROM `" . DB_PREFIX . "blog` WHERE `status` = ? ORDER BY `hits` DESC LIMIT 5", array(1));
		return $query->rows;
	}

	public function allDoctors() 
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "doctor` WHERE `status` = ?", array(1));
		return $query->rows;
	}

	public function allDepartments()
	{ 
		$query = $this->model->query("SELECT name, icon, description FROM `" . DB_PREFIX . "department` WHERE status = ?", array(1));
		return $query->rows;
	}


	public function homeServices()
	{
		$query = $this->model->query("SELECT `name`, `icon`, `priority` FROM `" . DB_PREFIX . "service` ORDER BY `priority` ASC LIMIT 6");
		return $query->rows;
	}

	public function allFacilities()
	{
		$query = $this->model->query("SELECT `name`, `icon`, `description` FROM `" . DB_PREFIX . "facility` WHERE `status` = ?", array(1));
		return $query->rows;
	}

	public function homeBlogs()
	{
		$query = $this->model->query("SELECT `id`, `title`, `short_post`, `picture`, `author`, `date_of_joining` AS `date` FROM `" . DB_PREFIX . "blog` ORDER BY `date_of_joining` DESC LIMIT 3");
		return $query->rows;
	}

	public function allServices()
	{
		$query = $this->model->query("SELECT id, name, icon, picture, short_post AS `description` FROM `" . DB_PREFIX . "service` WHERE status = ?", array(1) );
		return $query->rows;
	}

	public function getSingleService($id)
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "service` WHERE `id` = ? LIMIT 1", array((int)$id));
		return $query->row;
	}

	public function getSingleBlog($id)
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "blog` WHERE `id` = ? LIMIT 1", array((int)$id));
		if ($query->num_rows > 0) {
			$result = $query->row;
			$this->model->query("UPDATE `" . DB_PREFIX . "blog` SET `hits` = `hits` + 1 WHERE `id` = ?", array((int)$id));
			return $result;
		} else {
			return false;
		}
	}

	public function getComments($id)
	{
		$query = $this->model->query("SELECT `author`, `content`, `date_of_joining` FROM `" . DB_PREFIX . "comment` WHERE `blog_id` = ? AND `status` = ? ORDER BY date_of_joining DESC", array((int)$id, 1));
		if ($query->num_rows > 0) {
			return $query->rows;
		} else {
			return false;
		}
	}

	public function getCategories()
	{
		$query = $this->model->query("SELECT c.`id`, c.`name`, c.`slug`, c.`icon`, count(bc.`category_id`) as `count` FROM `" . DB_PREFIX . "category` AS c LEFT JOIN `" . DB_PREFIX . "blog_to_category` AS bc ON c.`id` = bc.`category_id` GROUP BY c.`id`");
		if ($query->num_rows > 0) {
			return $query->rows;
		} else {
			return false;
		}
	}

	public function allCategoryWithChild($id)
	{
		$query = $this->model->query("SELECT c1.`id` FROM `" . DB_PREFIX . "category` AS c LEFT JOIN `" . DB_PREFIX . "category` AS c1 ON c.`id` = c1.`parent` WHERE c.`id` = ? OR c.`parent` = ?", array((int)$id, (int)$id));
		if ($query->num_rows > 0) {
			return $query->rows;
		} else {
			return false;
		}
	}

	public function getBlogByCategory($list)
	{
		$query = $this->model->query("SELECT `blog_id` FROM `" . DB_PREFIX . "blog_to_category` WHERE `category_id` IN (".implode(',', $list).")");
		$blog_ids = array_unique(array_map(function($current){
			return $current['blog_id'];
		}, $query->rows));

		if ($query->num_rows > 0) {
			 $blog_query = $this->model->query("SELECT `id`, `title`, `short_post`, `picture`, `author`, `date_of_joining` AS `date` FROM `" . DB_PREFIX . "blog` WHERE `id` IN (".implode(',', $blog_ids).")");
			 return $blog_query->rows;
		} else {
			return false;
		}

	}

	public function getCategory($id)
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "category` WHERE `id` = ?", array((int)$id));
		if ($query->num_rows > 0) {
			return $query->row;
		} else {
			return false;
		}
	}

	public function allServiceReviews($id)
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "review` WHERE `review_for` = ? AND `review_for_id` = ? AND `status` = ? ORDER BY date_of_joining DESC", array(1, (int)$id, 1));
		if ($query->num_rows > 0) {
			return $query->rows;
		} else {
			return false;
		}
	}
}