<?php

/**
* User Model
*/
class User extends Model
{
	public function getAppointment($email, $user_id)
	{
		$query = $this->model->query("SELECT `id`, `appointment_id`, `name`, 'email', `date`, `time`, `department_id` AS `department`, doctor_id AS `doctor`, `invoice_id`, `status`, `note` FROM `" . DB_PREFIX . "appointment` WHERE `email` = ? OR `user_id` =? ORDER BY `date` DESC", array($this->model->escape($email), $this->model->escape($user_id)));
		return $query->rows;
	}

	public function getAppointmentView($email, $id)
	{
		$query = $this->model->query("SELECT a.*, d.name AS doctor, dp.name AS department FROM `" . DB_PREFIX . "appointment` AS a LEFT JOIN `" . DB_PREFIX . "doctor` AS d ON d.id = a.doctor_id LEFT JOIN `" . DB_PREFIX . "department` AS dp ON dp.id = a.department_id WHERE a.email = ? AND a.id = ? LIMIT 1", array($this->model->escape($email), $this->model->escape($id)));
		
		return $query->row;
	}

	public function checkPrescription($id)
	{
		$query = $this->model->query("SELECT `id` FROM `" . DB_PREFIX . "prescription` WHERE `appointment_id` = ?", array($id));
		return $query->row;
	}

	public function getPrescription($email, $id)
	{
		$query = $this->model->query("SELECT p.*, a.name AS patient, d.name AS doctor, d.about FROM `" . DB_PREFIX . "prescription` AS p LEFT JOIN `" . DB_PREFIX . "appointment` AS a ON a.id = p.appointment_id LEFT JOIN `" . DB_PREFIX . "doctor` AS d ON d.id = a.doctor_id WHERE p.email = ? AND p.appointment_id = ?", array($email, $id));
		return $query->row;
	}

	public function getReports($id)
	{
		$query = $this->model->query("SELECT `id`, `report` FROM `" . DB_PREFIX . "reports` WHERE `appointment_id` = ?", array((int)$id));
		if ($query->num_rows > 0) {
			return  $query->rows;
		} else {
			return false;
		}
	}

	public function doctors()
	{
		$query = $this->model->query("SELECT `id`, `name` FROM `" . DB_PREFIX . "doctor`");
		return $query->rows;
	}

	public function getRequest($email, $user_id)
	{
		$query = $this->model->query("SELECT * FROM `" . DB_PREFIX . "request` WHERE `email` = ? OR `user_id` =? ", array( $this->model->escape($email), $this->model->escape($user_id)));
		return $query->rows;
	}

	public function invoices($email, $user_id)
	{
		$query = $this->model->query("SELECT i.id, i.name, i.amount, i.paid, i.due, d.name AS doctor, c.name AS currency, c.abbr AS abbr, p.name AS method FROM `" . DB_PREFIX . "invoice` AS i LEFT JOIN `" . DB_PREFIX . "currency` AS c ON c.id = i.currency LEFT JOIN `" . DB_PREFIX . "payment_method` AS p ON p.id = i.method LEFT JOIN `" . DB_PREFIX . "doctor` AS d ON d.id = i.doctor_id WHERE i.email = '".$email."' OR i.user_id = '".(int)$user_id."' ORDER BY i.date_of_joining DESC");
		return $query->rows;
	}

	public function getUserData($user_id)
	{
		$query = $this->model->query("SELECT `firstname`, `lastname`, `email`, `mobile`, `location`, `bloodgroup`, `gender`, `about`, `dob`, `country` FROM `" . DB_PREFIX . "users` WHERE `user_id` = ? AND `status` = ? LIMIT 1", array( $this->model->escape($user_id), 1));
		return $query->row;
	}

	public function getInvoice($id)
	{
		$query = $this->model->query("SELECT i.*, d.name AS doctor, c.name AS currency, c.abbr AS abbr, p.name AS method FROM `" . DB_PREFIX . "invoice` AS i LEFT JOIN `" . DB_PREFIX . "currency` AS c ON c.id = i.currency LEFT JOIN `" . DB_PREFIX . "payment_method` AS p ON p.id = i.method LEFT JOIN `" . DB_PREFIX . "doctor` AS d ON d.id = i.doctor_id WHERE i.id = '".(int)$id."'");
		return $query->row;
	}

	public function createRequest($data)
	{
		$query = $this->model->query("INSERT INTO `" . DB_PREFIX . "request` (`name`, `email`, `mobile`, `subject`, `message`, `user_id`) VALUES (?, ?, ?, ?, ?, ?)", array($this->model->escape($data['name']), $this->model->escape($data['email']), $this->model->escape($data['mobile']), $data['subject'], $data['message'], $data['user_id']));
		if ($query->num_rows > 0) {
			return true;
		} else {
			return false;
		}
	}

	public function checkUserEmail($data)
	{
		$query = $this->model->query("SELECT `email` FROM `" . DB_PREFIX . "users` WHERE `user_id` = ? and `email` = ? LIMIT 1", array($this->model->escape($data['user_id']), $this->model->escape($data['email'])));
		if ($query->num_rows > 0) {
			return true;
		} else {
			return false;
		}
	}

	public function updateUser($data)
	{
		$query = $this->model->query("UPDATE `" . DB_PREFIX . "users` SET `mobile` = ?, `location` = ?, `country` = ?, `bloodgroup` = ?, `gender` = ?, `dob` = ? WHERE `user_id` = ?" , array($this->model->escape($data['mobile']), $this->model->escape($data['location']), $this->model->escape($data['country']), $this->model->escape($data['bloodgroup']), (int)$data['gender'], $this->model->escape($data['dob']), (int)$data['user_id']));
		if ($query->num_rows > 0) {
			return true;
		} else {
			return false;
		}
	}

	public function getPassword($data)
	{
		$query = $this->model->query("SELECT `firstname`, `lastname`, `email`, `password` FROM `" . DB_PREFIX . "users` WHERE `user_id` = ? AND `email` = ? LIMIT 1", array($this->model->escape($data['user_id']), $this->model->escape($data['email'])));
		if ($query->num_rows > 0) {
			return $query->row;
		} else {
			return false;
		}
	}

	public function updatePassword($data)
	{
		$passwordhash = password_hash($data['new'], PASSWORD_DEFAULT);
		$query = $this->model->query("UPDATE `" . DB_PREFIX . "users` SET `password` = ? WHERE `email` = ? AND `user_id` = ?", array($this->model->escape($passwordhash), $this->model->escape($data['email']), (int)$data['user_id']));
		if ($query->num_rows > 0) {
			return true;
		} else {
			return false;
		}
	}
}